// app/actions/getCompatibleVehicles.js
'use server';
export async function getCompatibleVehicles(
  model: string,
  filterOptions: {
    type: string;
    position: string;
    sort: string;
  }
) {
  const { type, position, sort } = filterOptions;
  let apiUrl = `http://node.tvseurogrip.com:3000/api/v1/compatible-vehicle-list/${model}`;
  // let apiUrl;
  // if (process.env.NODE_ENV === 'production') {
  //   apiUrl = `${process.env.PROD_API_URL}/api/v1/compatible-vehicle-list/${model}`;
  // } else {
  //   apiUrl = `${process.env.DEV_API_URL}/api/v1/compatible-vehicle-list/${model}`;
  // }

  // Initialize query parameters
  const queryParams = new URLSearchParams();

  // Add query parameters if they exist
  if (type) queryParams.append('type', type);
  if (position) queryParams.append('pos', position);
  if (sort) queryParams.append('sort', sort);

  // Append query parameters to the API URL
  if (queryParams.toString()) {
    apiUrl += `?${queryParams.toString()}`;
  }

  try {
    // Fetch data from the API
    const response = await fetch(apiUrl, {
      method: 'GET',
      headers: {
        'Content-Type': 'application/json',
      },
      cache: 'no-store', // Avoid caching for dynamic data
    });

    if (!response.ok) {
      throw new Error(`Failed to fetch: ${response.statusText}`);
    }

    // Parse the JSON response
    const data = await response.json();
    return data;
  } catch (error) {
    console.error('Error fetching compatible vehicles:', error);
    throw new Error('Could not fetch compatible vehicle list');
  }
}
