"use client";
import StatisticsCard from "@/components/shared/statistics-card";
import Image from "next/image";
import Breadcrumbs from "@/components/shared/Breadcrumbs";
import TwoColumnLayout from "@/components/shared/two-column-layout";
import BoxContainer from "@/components/shared/box-container";
import Link from "next/link";
import { ArrowUpCircle, CheckCircle, Clock3 } from "lucide-react";

export default function AboutEurogrip() {
  const tyreCategories = [
    "Two-wheeler tyres",
    "Three-wheeler tyres",
    "Ultra Light Truck tyres",
    "Small Commercial Vehicle tyres",
    "Agriculture & Farm tyres",
    "Industrial tyres",
    "Construction tyres"
  ];

  const trustedChoices = [
    {
      "src": "https://tvseurogrip.com/wp-content/uploads/2022/01/PRODUCT-PORTFOLIO-IMG1.png",
      "title": "Two & Three-wheeler tyres",
      "link": "https://tvseurogrip.com/product-category/two-three-wheeler-tyres/"
    },
    {
      "src": "https://tvseurogrip.com/wp-content/uploads/2022/01/PRODUCT-PORTFOLIO-IMG2.png",
      "title": "Industrial Pneumatic tyres",
      "link": "https://tvseurogrip.com/product-category/industrial-pneumatic-tyres/"
    },
    {
      "src": "https://tvseurogrip.com/wp-content/uploads/2022/01/PRODUCT-PORTFOLIO-IMG3.png",
      "title": "All - Terrain Vehicle tyres",
      "link": "https://tvseurogrip.com/product-category/all-terrain-vehicle-tyres/"
    },
    {
      "src": "https://tvseurogrip.com/wp-content/uploads/2022/01/PRODUCT-PORTFOLIO-IMG4.png",
      "title": "Skid-steer construction tyres",
      "link": "https://tvseurogrip.com/product-category/skid-steer-construction-tyres/"
    },
    {
      "src": "https://tvseurogrip.com/wp-content/uploads/2022/01/PRODUCT-PORTFOLIO-IMG5.png",
      "title": "Multi-purpose agriculture tyres",
      "link": "https://tvseurogrip.com/product-category/multi-purpose-agriculture-tyres/"
    },
    {
      "src": "https://tvseurogrip.com/wp-content/uploads/2022/01/PRODUCT-PORTFOLIO-IMG6.png",
      "title": "OTR tyres",
      "link": "https://tvseurogrip.com/product-category/otr-tyres/"
    }
  ]

  const performanceObj = [
    {
      "backgroundUrl": 'url("https://tvseurogrip.com/wp-content/uploads/2022/01/about-brand-outlive.jpg")',
      "icon": <ArrowUpCircle className="h-6 w-6 text-white" strokeWidth={3} />,
      "title": "OUTLIVE",
      "description": "Long-lasting, high performance tyre designed to outlive every journey."
    },
    {
      "backgroundUrl": 'url("https://tvseurogrip.com/wp-content/uploads/2022/01/about-brand-outperform.jpg")',
      "icon": <CheckCircle className="h-6 w-6 text-white" strokeWidth={3} />,
      "title": "OUTPERFORM",
      "description": "Crafted with engineering precision, technological acumen and designed by global research centres, our specialist tyre will outperform on any road condition."
    },
    {
      "backgroundUrl": 'url("https://tvseurogrip.com/wp-content/uploads/2022/01/about-brand-outdo.jpg")',
      "icon": <Clock3 className="h-6 w-6 text-white" strokeWidth={3} />,
      "title": "OUTDO",
      "description": "Designed to deliver high performance, our tyre is always ready for the next journey. It will empower you to outdo what was done yesterday!"
    }
  ]


  const factoryImage =
    "https://tvseurogrip.com/wp-content/uploads/2022/02/teg-Factory-picture.jpg";
  const journeyVideo = 'https://www.youtube.com/embed/4uR5XYXVPT8?feature=oembed&wmode=opaque&autoplay=0&loop=0&controls=1&mute=0&rel=0&modestbranding=0'
  const vehicleTypes = 'https://tvseurogrip.com/wp-content/uploads/2022/01/teg-about-us-portfolio.png'
  const tyres = 'https://tvseurogrip.com/wp-content/uploads/2021/11/mainpage-lifetime-warranty.jpg'
  const JourneyText = () => <> <p>About TVS Eurogrip: TVS Srichakra Limited, makers of TVS Eurogrip brand of tyres is one of India’s leading manufacturers and exporters of Two, Three-Wheeler tyres and Off-Highway tyres. With global research and development capabilities and cutting-edge technology, TVS Srichakra produces industry leading tyres for the automotive sector in India and worldwide.</p>
    <br />
    <p>Incorporated in 1982 & headquartered in Madurai, TVS Srichakra has manufacturing facilities in Madurai (Tamil Nadu) and Pantnagar (Uttarakhand) with a production capacity of over 3 million tyres a month. The company has a design centre in Milan, Italy supporting the R&D centre in Madurai and the tyres are tested in Indian, European, and Japanese road conditions. TVS Srichakra’s products are available in over 85 countries across the world. In India, the company enjoys a significant market share amongst the original equipment manufacturers and replacement markets and has a comprehensive network of distributors and dealers giving it a robust presence.</p>
  </>
  const JourneyVideoComponent = () => <iframe
    src={journeyVideo}
    allowFullScreen
    loading="lazy"
    title="Eurogrip"
    className="w-full sm:w-[48%]  sm:pr-4"
  />
  const VehicleTypesComponent = ({ imageSrc, altDesc, widthClass = '' }: { imageSrc: string, altDesc: string, widthClass: string }) => <Image
    src={imageSrc || "/placeholder.svg"}
    alt={altDesc}
    width={500}
    height={500}
    className={`object-fit w-full ${widthClass}  sm:pr-4`}
  />
  const PerformanceComponent = ({ backgroundUrl, icon, title, description }: { backgroundUrl: string, icon: any, title: string, description: string }) =>
    <div
      className="relative h-96 w-[30%] transform -skew-x-6 overflow-hidden shadow-xl  group">
      <div
        className="absolute inset-0 transition-transform duration-500 group-hover:scale-110"
        style={{
          backgroundImage: backgroundUrl,
          backgroundSize: "cover",
          backgroundPosition: "center",
        }}
      />
      <div className="absolute inset-0 bg-black/40">
        <div className="flex flex-col items-center justify-center h-full text-white skew-x-6 px-6">
          <div className=" p-4 mb-4">
            {icon}
          </div>
          <h2 className="text-3xl font-bold tracking-wider mb-4">{title}</h2>
          <p className="text-center text-sm max-w-xs">
            {description}
          </p>
        </div>
      </div>
    </div>
  return (
    <div className="">
      <div className="mb-5">
        <Breadcrumbs />
      </div>
      <div className="">
        <div className="relative w-full h-[600px] mt-5">
          <Image
            src={factoryImage || "/placeholder.svg"}
            alt={"eg Factory picture"}
            fill
            className="object-cover md:hidden"
            sizes="100vw"
          />
          <Image
            src={factoryImage || "/placeholder.svg"}
            alt={"eg Factory picture"}
            fill
            className="hidden md:block object-cover"
            sizes="100vw"
          />
          <div style={{transform: 'scale(1)',transition: 'all 1s'}}  className="absolute inset-0 flex items-center justify-center">
            <div className=" bg-gray-800/50 py-8">
              <h1 className="text-center text-white text-4xl md:text-4xl font-bold tracking-wider px-4">
                FACTORY OF EUROGRIP
              </h1>
            </div>
          </div>
        </div>
      </div>
      <TwoColumnLayout leftSrc={<JourneyVideoComponent />} rightSrc={<JourneyText />} />
      <StatisticsCard />
      <BoxContainer>
        <div className="container my-[5%] flex flex-wrap text-sm/6 text-gray-600">
          <div className="relative sm:w-[48%]">
            <VehicleTypesComponent imageSrc={tyres} altDesc="About Eurogrip " widthClass="w-full" />
            <div className="absolute top-0 left-0 px-5 pt-3 pb-3 text-white">
              <h1 className="text-xl">EUROGRIP HAS TYRES FOR VARIED NEEDS</h1>
              <p className="text-l pt-3 pb-2 pr-3">With tyres rolling out of our state-of-the-art manufacturing units at Madurai (Tamil Nadu) and Pantnagar (Uttarakhand) sprawling over 2.9 lakh sq. m., we specialise in:</p>
              <ul className="list-disc pl-5">
                {tyreCategories.map((tyre, index) => (
                  <li key={index} className="text-sm py-[2px]">
                    {tyre}
                  </li>
                ))}
              </ul>
            </div>
          </div>
          <VehicleTypesComponent widthClass="sm:w-[48%]" imageSrc={vehicleTypes} altDesc="About Eurogrip " />
        </div>
      </BoxContainer>
      <div className="w-full bg-gray-100 py-[6%] my-[4%]">
        <BoxContainer>
          <h1 className="text-4xl text-center py-5 text-sky-700 font-medium">EUROGRIP - THE TRUSTED CHOICE OF OEM SEGMENT</h1>
          <div className="flex  justify-between">
            {trustedChoices.map((choice,i) =>
              <Link key={i} className="w-[160px]" href={choice.link} target="_blank">
                <Image
                  src={choice.src || "/placeholder.svg"}
                  alt={choice.title}
                  className="hidden md:block object-cover"
                  width={160}
                  height={160}
                />
                <h3 className="my-5 text-wrap text-l mt-10 text-center font-bold">{choice.title}</h3>
              </Link>
            )}

          </div>
        </BoxContainer>
      </div>
      <BoxContainer>
        <div className="w-full py-[6%] my-[4%] text-center text-gray-400 text-sm/6">
          <h1 className="text-4xl text-center py-5 text-sky-700 font-medium">HIGH PERFORMANCE SPECIALIST TYRES</h1>
          <p>Bikes these days have gone beyond a motor transportation. They are an extension of their millennial riders who constantly seek new experiences and adventure. Every ride is a quest for the next best thing. These riders don’t believe in succeeding in a one-dimensional way but want to experience life while succeeding.
          </p>
          <p>Powered by global design and technological acumen, TVS Eurogrip is the Bike Tyre Specialist that reflects this ambition of the new generation.
          </p>
          <p className="font-bold mt-2">It is a promise that our brand will – OUTLIVE, OUTPERFORM & OUTDO. </p>
        </div>
      </BoxContainer>
      <BoxContainer>
        <div className="flex justify-between pb-[6%] mb-[4%]">
          {performanceObj.map((obj,i) => <PerformanceComponent key={i} {...obj} />)}
        </div>
      </BoxContainer>
    </div>
  );
}
