'use client';
import { useCartStore } from '@/store/useCartStore';
import { Button } from '@/components/ui/button';
import { X, Minus, Plus, ChevronUp, ChevronDown } from 'lucide-react';
import Link from 'next/link';
import React, { useEffect, useState } from 'react';
import Image from 'next/image';
import { Input } from '@/components/ui/input';
import BoxContainer from '@/components/shared/box-container';

const Page = () => {
  const {
    items,
    removeItemCart,
    increaseQuantity,
    decreaseQuantity,
    total,
    discountedTotal,
    coupon,
    applyCoupon,
    removeCoupon,
  } = useCartStore();
  const [mounted, setMounted] = useState(false);
  const [isCouponOpen, setIsCouponOpen] = useState(false);
  const [couponCode, setCouponCode] = useState('');

  useEffect(() => {
    setMounted(true);
  }, []);

  if (!mounted) {
    return null;
  }

  const handleApplyCoupon = () => {
    applyCoupon(couponCode);
    setCouponCode('');
  };

  return (
    <BoxContainer>
      {/* Top section */}
      <div className='flex justify-between items-center px-4 py-2 border-b mb-4'>
        <h2 className='text-[24px] font-semibold'>Review Your Cart</h2>
      </div>

      {/* Middle section (scrollable) */}
      <div className='flex-grow overflow-y-auto p-4'>
        {items.length === 0 ? (
          <p>Your cart is empty</p>
        ) : (
          items.map((item) => (
            <div
              key={item.id}
              className='flex justify-between items-start mb-[30px] gap-2 relative'
            >
              <Image
                src={item?.image}
                width={50}
                height={50}
                alt={item?.title}
                // style={{ width: '100%' }}
                className='w-[50px] h-[50px] border border-[#cccccc]'
              />
              <div className='title-quantity'>
                <h3 className='text-[14px] font-semibold'>{item.title}</h3>
                <div className='border border-[#cccccc] w-[fit-content] rounded-[10px]'>
                  <button
                    onClick={() => decreaseQuantity(item.id)}
                    className='px-2 border-l-[1px] border-[#cccccc] text-[12px]'
                  >
                    <Minus className='h-3 w-3 ' />
                  </button>
                  <span className='px-1 py-1 inline-block text-[12px]'>
                    {item.quantity}
                  </span>
                  <button
                    onClick={() => increaseQuantity(item.id)}
                    className='px-2 border-r border-[#cccccc] text-[12px]'
                  >
                    <Plus className='h-3 w-3' />
                  </button>
                </div>
              </div>
              <div className='flex gap-2'>
                <p className='text-[18px] text-gray-500'>
                  ₹{parseFloat(item.price).toFixed(2)}
                </p>
              </div>
              <button
                className='bg-[#e8e8e8] ml-2 absolute top-[-10px] left-[-12px] rounded-[50%] w-[30xp] h-[25px] p-1'
                onClick={() => removeItemCart(item.id)}
              >
                <X className='h-3 w-3' />
              </button>
            </div>
          ))
        )}
      </div>

      {/* Bottom section */}
      <div className='bottom-section mb-5'>
        <div className='w-full border-t border-b pt-4 px-5'>
          <button
            className='w-full mb-2 text-left flex justify-between'
            onClick={() => setIsCouponOpen(!isCouponOpen)}
          >
            <span className='text-[16px] font-semibold '>
              Got a discount code?
            </span>
            {isCouponOpen ? (
              <ChevronUp className='ml-2 h-4 w-4' />
            ) : (
              <ChevronDown className='ml-2 h-4 w-4' />
            )}
          </button>
          {isCouponOpen && (
            <div className='mb-4 flex'>
              <Input
                type='text'
                placeholder='Enter coupon code'
                value={couponCode}
                onChange={(e) => setCouponCode(e.target.value)}
                className='mr-2'
              />
              <Button onClick={handleApplyCoupon}>Apply</Button>
            </div>
          )}
          {coupon && (
            <div className='mb-2 flex justify-between items-center'>
              <span>Coupon applied: {coupon.code}</span>
              <Button variant='ghost' size='sm' onClick={removeCoupon}>
                Remove
              </Button>
            </div>
          )}
        </div>
        <div className='w-full pt-4 px-5'>
          <p className='font-bold text-lg'>Subtotal: ₹{total().toFixed(2)}</p>
          {coupon && (
            <p className='text-green-600'>
              Discount: ₹{(total() - discountedTotal()).toFixed(2)}
            </p>
          )}
          <p className='font-bold text-xl mt-2'>
            Total: ₹{discountedTotal().toFixed(2)}
          </p>
          {/* <Button onClick={clearCart} className='mt-4 w-full'>
                Clear Cart
              </Button> */}
          {items?.length > 0 && (
            <Link
              className='p-2 bg-[#cccccc] w-full mt-4 mb-4 block'
              href={'/checkout'}
            >
              Checkout
            </Link>
          )}
        </div>
      </div>
    </BoxContainer>
  );
};

export default Page;
