"use client";
import Image from "next/image";
import Breadcrumbs from "@/components/shared/Breadcrumbs";
import BoxContainer from "@/components/shared/box-container";
import Link from "next/link";
import GloballyCertifiedSection from "@/components/shared/global-certification-section";

export default function Certifications() {
  const bannerImage =
    "https://tvseurogrip.com/wp-content/uploads/2022/01/Certifications-page-banner.jpg";

  const certificates = [
    {
      image:
        "https://tvseurogrip.com/wp-content/uploads/2022/01/ISO-9001-Certificate-MDU.jpg",
      title: "ISO 9001 : 2015 QUALITY",
      certificateNo: "Certificate # : 0073041",
      validity: "Valid till 04 March 2027",
      href: "https://tvseurogrip.com/wp-content/uploads/2023/08/ISO-9001-Certificate-MDU-MPD-25072024.pdf",
    },
    {
      image:
        "https://tvseurogrip.com/wp-content/uploads/2022/01/IATF-16949-Certificate-MDU-1.jpg",
      title: "IATF 16949 : 2016 QUALITY",
      certificateNo: "Certificate # : 0506500",
      validity: "Valid till 19 March 2027",
      href: "https://tvseurogrip.com/wp-content/uploads/2023/08/IATF-16949-Certificate-MDU-WHS-25072024.pdf",
    },
    {
      image:
        "https://tvseurogrip.com/wp-content/uploads/2022/01/ISO-14001-Certificate-MDU.jpg.webp",
      title: "ISO 14001:2015 ENVIRONMENT",
      certificateNo: "Certificate # : 0073040",
      validity: "Valid till 04 March 2027",
      href: "https://tvseurogrip.com/wp-content/uploads/2023/08/ISO-14001-Certificate-MDU-MPD-25072024.pdf",
    },
    {
      image:
        "https://tvseurogrip.com/wp-content/uploads/2022/01/ISO-45001-Certificate-MDU.jpg.webp",
      title: "ISO 45001 : 2018 OH SAFETY",
      certificateNo: "Certificate # : 0100468",
      validity: "Valid till 4 April 2026",
      href: "https://tvseurogrip.com/wp-content/uploads/2023/05/0100468_ENG_TVS_Srichakra_Limited.pdf",
    },
  ];

  return (
    <div className="overflow-auto">
      <div className="mb-5">
        <Breadcrumbs />
      </div>
      {/* Hero Banner with Certifications */}
      <div className="relative w-full h-[500px] my-10">
        <Image
          src={bannerImage || "/placeholder.svg"}
          alt={"eg Factory picture"}
          fill
          className="object-cover md:hidden"
          sizes="100vw"
        />
        <Image
          src={bannerImage || "/placeholder.svg"}
          alt={"eg Factory picture"}
          fill
          className="hidden md:block object-cover"
          sizes="100vw"
        />
        <div className="absolute inset-0 flex items-center justify-center">
          <h1 className="text-center w-[30%] text-white text-2xl md:text-2xl font-bold tracking-wider  ml-[1.5rem]">
            CERTIFICATIONS
          </h1>
        </div>
      </div>

      {/* Quality Philosophy Section */}
      <BoxContainer>
        <div className="container mx-auto my-[8%] px-4">
          <div className="flex flex-col md:flex-row gap-8 md:gap-16 relative">
            {/* Vertical line that spans the full height */}
            <div className="absolute left-0 top-0 bottom-0 w-1 bg-[#D4AF37] hidden md:block"></div>

            <div className="md:w-1/3 md:pl-6">
              <h2 className="text-deep-indigo text-3xl md:text-4xl font-bold leading-tight">
                QUALITY
                <br />
                PHILOSOPHY
              </h2>
            </div>

            <div className="md:w-2/3 grid grid-cols-1 md:grid-cols-2 gap-8">
              <div>
                <p className="text-gray-600 leading-relaxed">
                  We promise customer happiness by persevering towards
                  impeccable quality of our products and services.
                </p>
              </div>
              <div>
                <p className="text-gray-600 leading-relaxed">
                  We do so seamlessly by involving all our employees and
                  business partners in this journey towards excellence and
                  achieving global standards in quality.
                </p>
              </div>
            </div>
          </div>
        </div>
      </BoxContainer>
      <BoxContainer>
        <div className="mt-[10%]">
          <h1 className="text-2xl sm:text-3xl md:text-4xl font-bold text-tegblue text-center mb-8 sm:mb-12">
            Policies
          </h1>
          <div className="bg-gray-100 py-[10%] sm:py-12 md:py-[10%]">
            <div className="flex flex-col md:flex-row justify-center items-center">
              <div className="text-center w-full md:w-1/2 max-w-lg mx-auto">
                <Link
                  className="w-[160px]"
                  href={
                    "https://tvseurogrip.com/wp-content/uploads/2023/04/OHSE-Policy.pdf"
                  }
                  target="_blank"
                >
                  <div className="flex flex-col justify-center items-center">
                    <div className="w-[75%] mb-4 sm:mb-6">
                      <Image
                        src="https://tvseurogrip.com/wp-content/uploads/2023/04/OHSE-Policy.jpg"
                        alt="Quality Policy Certificate"
                        width={400}
                        height={566}
                        sizes="(max-width: 768px) 75vw, (max-width: 1200px) 38vw, 300px"
                        className="w-full h-auto"
                      />
                    </div>
                    <h2 className="text-xl sm:text-2xl font-bold text-gray-900">
                      QUALITY POLICY
                    </h2>
                  </div>
                </Link>
              </div>
              <div className="text-center w-full md:w-1/2 max-w-lg mx-auto mt-8 md:mt-0">
                <Link
                  className="w-[160px]"
                  href={
                    "https://tvseurogrip.com/wp-content/uploads/2023/05/0100468_ENG_TVS_Srichakra_Limited.pdf"
                  }
                  target="_blank"
                >
                  <div className="flex flex-col justify-center items-center">
                    <div className="w-[75%] mb-4 sm:mb-6">
                      <Image
                        src="https://tvseurogrip.com/wp-content/uploads/2022/01/Environmental-Policy.jpg"
                        alt="Environmental Policy Certificate"
                        width={400}
                        height={566}
                        sizes="(max-width: 768px) 75vw, (max-width: 1200px) 38vw, 300px"
                        className="w-full h-auto"
                      />
                    </div>
                    <h2 className="text-xl sm:text-2xl font-bold text-gray-900">
                      ENVIRONMENTAL POLICY
                    </h2>
                  </div>
                </Link>
              </div>
            </div>
          </div>
        </div>
      </BoxContainer>
      <BoxContainer>
        <div className="py-[10%] sm:py-12 md:py-[10%]">
          <div className="container mx-auto px-4">
            <h1 className="text-2xl sm:text-3xl md:text-4xl font-bold text-tegblue text-center mb-8 sm:mb-12">
              CERTIFICATIONS 2025
            </h1>

            <div className="grid grid-cols-1 sm:grid-cols-2 lg:grid-cols-4 gap-8">
              {certificates.map((cert, index) => (
                <Link key={index} href={cert.href} target="_blank">
                  <div className="flex flex-col items-center">
                    <div className="w-full max-w-xs mb-4">
                      <Image
                        src={cert.image || "/placeholder.svg"}
                        alt={cert.title}
                        width={320}
                        height={450}
                        sizes="(max-width: 640px) 90vw, (max-width: 1024px) 50vw, 320px"
                        className="w-full h-auto"
                      />
                    </div>
                    <h2 className="text-lg font-bold text-gray-900 text-center mb-2">
                      {cert.title}
                    </h2>
                    <p className="text-sm text-gray-600 text-center mb-1">
                      {cert.certificateNo}
                    </p>
                    <p className="text-sm text-gray-600 text-center">
                      {cert.validity}
                    </p>
                  </div>
                </Link>
              ))}
            </div>
          </div>
        </div>
      </BoxContainer>
      <BoxContainer>
        <div className="container mx-auto px-4 py-12 mb-[8%] h-[70%]">
          <div className="flex flex-col md:flex-row items-start">
            {/* Heading with vertical line */}
            <div className="relative mb-8 md:mb-0 md:w-1/4 md:mr-8">
              <div className="absolute left-0 top-0 w-1 h-full bg-amber-400"></div>
              <div className="text-2xl sm:text-3xl md:text-4xl font-semibold text-navy-900 pl-6">
                <div className="leading-relaxed">GLOBALLY</div>
                <div className="leading-relaxed">TESTED &</div>
                <div className="leading-relaxed">CERTIFIED</div>
                <div className="leading-relaxed">PRODUCTS</div>
              </div>
            </div>
            <GloballyCertifiedSection />
          </div>
        </div>
      </BoxContainer>

      {/* Footer would go here */}
    </div>
  );
}
