'use client';
import { useComparisonStore } from '@/store/useComparisonStore';
import {
  faCartShopping,
  faTrashCan,
  faXmark,
} from '@fortawesome/free-solid-svg-icons';
import { FontAwesomeIcon } from '@fortawesome/react-fontawesome';
import Image from 'next/image';
import Link from 'next/link';
import { SecureHTMLRenderer } from '@/components/shared/secure-html-renderer';
import { useCartStore } from '@/store/useCartStore';

const Page = () => {
  const { compareProducts } = useComparisonStore();
  return (
    <div className='w-full'>
      <header className='w-full flex justify-between items-center mb-5'>
        <h1 className='text-[36px] font-semibold mt-5 mb-2'>
          Compare Products
        </h1>
        {compareProducts.length > 0 && <ClearCompareProducts />}
      </header>
      {compareProducts.length === 0 && (
        <p className='mt-5'>
          No products to compare. Go to{' '}
          <Link
            href='/products/two-wheeler'
            className='text-tegblue font-semibold'
          >
            products
          </Link>{' '}
          page to add products to the comparison.
        </p>
      )}
      {compareProducts.length > 0 && (
        <>
          <div className='w-full'>
            <table className='teg-compare-table'>
              <tbody className='teg-compare-table-body'>
                <tr className='teg-compare-table-row'>
                  <th className='teg-compare-table-heading'>Items Compared</th>
                  {compareProducts?.map((item, ind) => {
                    return (
                      <td
                        key={ind}
                        className='teg-compare-table-cell teg-compare-item'
                      >
                        <RemoveBtn id={item?.id} />
                      </td>
                    );
                  })}
                </tr>
                <tr className='teg-compare-table-row'>
                  <th className='teg-compare-table-heading'>Product Image</th>
                  {compareProducts?.map((item, ind) => {
                    // Get the first image from the images array
                    const imageUrl =
                      item?.images && item.images.length > 0
                        ? item.images[0].url
                        : '/placeholder.svg';

                    return (
                      <td
                        key={ind}
                        className='teg-compare-table-cell teg-compare-item'
                      >
                        <Image
                          src={imageUrl || '/placeholder.svg'}
                          width={180}
                          height={180}
                          alt={item?.title}
                          className='w-[180px] h-[180px] m-auto object-contain'
                        />
                      </td>
                    );
                  })}
                </tr>
                <tr className='teg-compare-table-row'>
                  <th className='teg-compare-table-heading'>Product Name</th>
                  {compareProducts?.map((item, ind) => {
                    return (
                      <td
                        key={ind}
                        className='teg-compare-table-cell teg-compare-item'
                      >
                        <span className='text-tegred uppercase text-[14px] font-semibold'>
                          {item?.title}
                        </span>
                      </td>
                    );
                  })}
                </tr>
                <tr className='teg-compare-table-row'>
                  <th className='teg-compare-table-heading'>Price</th>
                  {compareProducts?.map((item, ind) => {
                    return (
                      <td
                        key={ind}
                        className='teg-compare-table-cell teg-compare-item'
                      >
                        <bdi className='text-tegblue text-[18px] font-semibold'>
                          ₹{item?.price}
                        </bdi>
                      </td>
                    );
                  })}
                </tr>
                <tr className='teg-compare-table-row'>
                  <th className='teg-compare-table-heading'>Category</th>
                  {compareProducts?.map((item, ind) => {
                    // Get category from product_subcategory
                    const category =
                      item?.product_subcategory?.data?.attributes?.name || '-';

                    return (
                      <td
                        key={ind}
                        className='teg-compare-table-cell teg-compare-item'
                      >
                        <span className='text-tegblue'>{category}</span>
                      </td>
                    );
                  })}
                </tr>
                <tr className='teg-compare-table-row'>
                  <th className='teg-compare-table-heading'>Tubing</th>
                  {compareProducts?.map((item, ind) => {
                    // Find tubing attribute
                    const tubingAttr = item?.product_attributes?.data?.find(
                      (attr: any) => attr?.attributes?.slug?.includes('tubing')
                    );
                    const tubing =
                      tubingAttr?.attributes?.attributename?.replace(
                        'Tubing ',
                        ''
                      ) || '-';

                    return (
                      <td
                        key={ind}
                        className='teg-compare-table-cell teg-compare-item'
                      >
                        <span>{tubing}</span>
                      </td>
                    );
                  })}
                </tr>
                <tr className='teg-compare-table-row'>
                  <th className='teg-compare-table-heading'>Wheel Position</th>
                  {compareProducts?.map((item, ind) => {
                    return (
                      <td
                        key={ind}
                        className='teg-compare-table-cell teg-compare-item'
                      >
                        <span>{item?.wheelPosition || '-'}</span>
                      </td>
                    );
                  })}
                </tr>
                <tr className='teg-compare-table-row'>
                  <th className='teg-compare-table-heading'>Section Width</th>
                  {compareProducts?.map((item, ind) => {
                    // Find section width attribute
                    const widthAttr = item?.product_attributes?.data?.find(
                      (attr: any) =>
                        attr?.attributes?.slug?.includes('section-width')
                    );
                    const width =
                      widthAttr?.attributes?.attributename?.replace(
                        'Section Width ',
                        ''
                      ) || '-';

                    return (
                      <td
                        key={ind}
                        className='teg-compare-table-cell teg-compare-item'
                      >
                        <span>{width}</span>
                      </td>
                    );
                  })}
                </tr>
                <tr className='teg-compare-table-row'>
                  <th className='teg-compare-table-heading'>Aspect Ratio</th>
                  {compareProducts?.map((item, ind) => {
                    // Find aspect ratio attribute
                    const ratioAttr = item?.product_attributes?.data?.find(
                      (attr: any) =>
                        attr?.attributes?.slug?.includes('aspect-ratio')
                    );
                    const ratio =
                      ratioAttr?.attributes?.attributename?.replace(
                        'Aspect Ratio ',
                        ''
                      ) || '-';

                    return (
                      <td
                        key={ind}
                        className='teg-compare-table-cell teg-compare-item'
                      >
                        <span>{ratio}</span>
                      </td>
                    );
                  })}
                </tr>
                <tr className='teg-compare-table-row'>
                  <th className='teg-compare-table-heading'>Rim Diameter</th>
                  {compareProducts?.map((item, ind) => {
                    // Find rim diameter attribute
                    const diameterAttr = item?.product_attributes?.data?.find(
                      (attr: any) =>
                        attr?.attributes?.slug?.includes('rim-diameter')
                    );
                    const diameter =
                      diameterAttr?.attributes?.attributename?.replace(
                        'Rim Diameter ',
                        ''
                      ) || '-';

                    return (
                      <td
                        key={ind}
                        className='teg-compare-table-cell teg-compare-item'
                      >
                        <span>{diameter}</span>
                      </td>
                    );
                  })}
                </tr>
                <tr className='teg-compare-table-row'>
                  <th className='teg-compare-table-heading'>Load Index</th>
                  {compareProducts?.map((item, ind) => {
                    // Find load index attribute
                    const loadAttr = item?.product_attributes?.data?.find(
                      (attr: any) =>
                        attr?.attributes?.slug?.includes('load-index')
                    );
                    const load =
                      loadAttr?.attributes?.attributename?.replace(
                        'Load Index ',
                        ''
                      ) || '-';

                    return (
                      <td
                        key={ind}
                        className='teg-compare-table-cell teg-compare-item'
                      >
                        <span>{load}</span>
                      </td>
                    );
                  })}
                </tr>
                <tr className='teg-compare-table-row'>
                  <th className='teg-compare-table-heading'>Speed Rating</th>
                  {compareProducts?.map((item, ind) => {
                    // Find speed rating attribute
                    const speedAttr = item?.product_attributes?.data?.find(
                      (attr: any) =>
                        attr?.attributes?.slug?.includes('speed-rating')
                    );
                    const speed =
                      speedAttr?.attributes?.attributename?.replace(
                        'Speed Rating ',
                        ''
                      ) || '-';

                    return (
                      <td
                        key={ind}
                        className='teg-compare-table-cell teg-compare-item'
                      >
                        <span>{speed}</span>
                      </td>
                    );
                  })}
                </tr>
                <tr className='teg-compare-table-row'>
                  <th className='teg-compare-table-heading align-top'>
                    Product Details
                  </th>
                  {compareProducts?.map((item, ind) => {
                    return (
                      <td
                        key={ind}
                        className='teg-compare-table-cell teg-compare-item align-top'
                      >
                        <div className='teg-description-rich-text'>
                          <SecureHTMLRenderer
                            html={
                              item?.content || item?.shortdescription || '-'
                            }
                          />
                        </div>
                      </td>
                    );
                  })}
                </tr>
                <tr className='teg-compare-table-row'>
                  <th className='teg-compare-table-heading'>Purchase</th>
                  {compareProducts?.map((item, ind) => {
                    return (
                      <td
                        key={ind}
                        className='teg-compare-table-cell teg-compare-item'
                      >
                        <AddToCart product={item} />
                      </td>
                    );
                  })}
                </tr>
              </tbody>
            </table>
          </div>
        </>
      )}
    </div>
  );
};

const RemoveBtn = ({ id }: { id: number }) => {
  const { removeProduct } = useComparisonStore();
  return (
    <button
      className='teg-compare-item-remove-button'
      onClick={() => {
        removeProduct(id);
      }}
    >
      <FontAwesomeIcon icon={faTrashCan} />
      <span className='text'>Remove</span>
    </button>
  );
};

const AddToCart = ({ product }: { product: any }) => {
  const { addItemCart } = useCartStore();

  const handleAddToCart = () => {
    const imageUrl =
      product?.images && product.images.length > 0
        ? product.images[0].url
        : '/placeholder.svg';

    addItemCart({
      id: product.id,
      title: product.title,
      price: product.price,
      sku: product.sku || '',
      permalink: `/product/${product.slug}`,
      image: imageUrl,
    });
  };

  return (
    <button
      className='bg-tegred text-white px-3 py-2 flex gap-2 justify-center items-center m-auto'
      onClick={handleAddToCart}
    >
      <FontAwesomeIcon icon={faCartShopping} />
      <span className='text'>Add to cart</span>
    </button>
  );
};

const ClearCompareProducts = () => {
  const { clearComparison } = useComparisonStore();
  return (
    <button
      className='bg-tegblue text-white px-3 py-2 flex gap-2 justify-center items-center'
      onClick={clearComparison}
    >
      <FontAwesomeIcon icon={faXmark} />
      <span className='text'>Clear products</span>
    </button>
  );
};

export default Page;
