"use client";
import Image from "next/image";
import Breadcrumbs from "@/components/shared/Breadcrumbs";
import BoxContainer from "@/components/shared/box-container";
import {
  faCommentDots,
  faDirections,
  faHandshake,
  faStreetView,
} from "@fortawesome/free-solid-svg-icons";
import { FontAwesomeIcon } from "@fortawesome/react-fontawesome";
import type { IconDefinition } from "@fortawesome/fontawesome-svg-core";
import Link from "next/link";
import { useState } from "react";

interface ContactOptionProps {
  icon: IconDefinition;
  title: string;
  href: string;
}

let locationsData = {
  manufacturingUnits: [
    {
      id: "madurai",
      title: "Madurai:",
      name: "TVS Srichakra Limited",
      address: ["Vellaripati, Melur Taluk,", "Madurai – 625122"],
      phone: null,
      mapUrl:
        "https://www.google.com/maps/embed?pb=!1m18!1m12!1m3!1d62867.71318131327!2d78.2121044791016!3d9.99767929999999!2m3!1f0!2f0!3f0!3m2!1i1024!2i768!4f13.1!3m3!1m2!1s0x3b00c1075e0ee0f9%3A0xef134d49c6686752!2sTVS%20Srichakra%20Ltd.!5e0!3m2!1sen!2sin!4v1649409923704!5m2!1sen!2sin",
      coordinates: {
        lat: 9.997679,
        lng: 78.212104,
      },
    },
    {
      id: "uttarakhand",
      title: "Uttarakhand:",
      name: "TVS Srichakra Limited",
      address: [
        "Plot No. 7, Sector - 1, Integrated Industrial Estate, Sidcul, Pant Nagar, Rudrapur Tehsil, Kichha Dist.",
        "Uttarakhand – 263153",
      ],
      phone: "Tel :05944-250374",
      mapUrl:
        "https://www.google.com/maps/embed?pb=!1m18!1m12!1m3!1d3489.2181401031557!2d79.40315741415502!3d29.010531173624834!2m3!1f0!2f0!3f0!3m2!1i1024!2i768!4f13.1!3m3!1m2!1s0x39a0806d79fe9ab3%3A0x6e2bc3500cdb7c88!2sTVS%20Srichakra%20Ltd.%20Pantnagar!5e0!3m2!1sen!2sin!4v1649409985591!5m2!1sen!2sin",
      coordinates: {
        lat: 29.010531,
        lng: 79.403157,
      },
    },
  ],
  corporateOffices: [
    {
      id: "chennai-corporate",
      title: "Chennai:",
      name: "TVS Srichakra Limited",
      address: [
        "No. 10 Maharani Chinnamma Road, Venus Colony, Teynampet,",
        "Chennai - 600018",
      ],
      phone: null,
      mapUrl:
        "https://www.google.com/maps/embed?pb=!1m18!1m12!1m3!1d31095.5487259863!2d80.23462963955077!3d13.039262599999997!2m3!1f0!2f0!3f0!3m2!1i1024!2i768!4f13.1!3m3!1m2!1s0x3a5267b5283a3a63%3A0xd9d2b2052dfdc726!2sTVS%20Srichakra%20Ltd.%2C%20TVS%20TYRES.!5e0!3m2!1sen!2sin!4v1649410062945!5m2!1sen!2sin",
      coordinates: {
        lat: 13.039263,
        lng: 80.23463,
      },
    },
  ],
  marketingOffices: [
    {
      id: "chennai-marketing",
      title: "Chennai:",
      name: "TVS Srichakra Limited",
      address: [
        "Sudarsan Building, 5th Floor, 14 Whites Road,",
        "Chennai-600014",
      ],
      phone: "Tel :044-28526007 / 28526008 / 28526009",
      mapUrl:
        "https://www.google.com/maps/embed?pb=!1m18!1m12!1m3!1d3886.662440219174!2d80.25763871384453!3d13.05714561653055!2m3!1f0!2f0!3f0!3m2!1i1024!2i768!4f13.1!3m3!1m2!1s0x3a5266162eec8f03%3A0x9864b8b56f7ae1db!2sTvs%20Srichakra%20Limited!5e0!3m2!1sen!2sin!4v1649410110335!5m2!1sen!2sin",
      coordinates: {
        lat: 13.057146,
        lng: 80.257639,
      },
    },
  ],
};
export default function ContactUs() {
  const bannerImage =
    "	https://tvseurogrip.com/wp-content/uploads/2022/04/teg-contact-us-page.jpg";

  const contactOptions: ContactOptionProps[] = [
    {
      icon: faDirections,
      title: "Product Enquiry",
      href: "/product-enquiry",
    },
    {
      icon: faCommentDots,
      title: "Product Support",
      href: "/product-support",
    },
    {
      icon: faStreetView,
      title: "Become Our Dealer",
      href: "/become-our-dealer",
    },
    {
      icon: faHandshake,
      title: "Join Our Team",
      href: "/join-our-team-form",
    },
  ];

  function ContactOption({ icon, title, href }: ContactOptionProps) {
    return (
      <Link
        href={href}
        className="bg-gray-200 p-12 flex flex-col items-center justify-center text-center h-[200px]"
      >
        <div className="text-tegblue mb-4">
          <FontAwesomeIcon icon={icon} className="w-8 h-8" />
        </div>
        <h3 className="text-tegblue tracking-wide uppercase font-bold text-xl md:text-xl">
          {title}
        </h3>
      </Link>
    );
  }
  const offices = [
    {
      region: "West Mumbai",
      officename: "TVS Srichakra Limited",
      address: [
        "810, 8th floor, Ecostar, Vishweshwar Nagar Cross Road, Off Aarey Road, Goregaon East,",
        "Mumbai – 400063",
      ],
      phone: "Tel : 022-62368626",
    },
    {
      region: "West, Ahmedabad",
      officename: "TVS Srichakra Limited",
      address: [
        "B-307, Premium House, 3rd Floor, Opp. Gandhigram Railway Station,",
        "Ahmedabad – 380009",
      ],
      phone: "Tel : 079-26580181 / 26585571",
    },
    {
      region: "South, Bangalore",
      officename: "TVS Srichakra Limited",
      address: [
        "4, 9th Main, 1st Floor, Banashankari 2nd Stage, Beside Indian Oil Petrol Bunk,",
        "Bengaluru – 560070",
      ],
      phone: "Tel : 080 26716764",
    },
    {
      region: "South, Hyderabad",
      officename: "TVS Srichakra Limited",
      address: [
        "City Centre Building, Door No. 3-6-140/A/201, 2nd Flr, Himayath Nagar, Hyderabad – 500029",
      ],
      phone: "Tel : 040-23222388",
    },
    {
      region: "North, Delhi",
      officename: "TVS Srichakra Limited",
      address: [
        "A-41, FIEE Complex Okhla Industrial Area, Phase II, New Delhi – 110020",
      ],
      phone: "Tel : 011-41422064 / 011-41422065",
    },
    {
      region: "East, Kolkata",
      officename: "TVS Srichakra Limited",
      address: [
        "R No. 204, PS-IXL Building, Near Hotel Holiday Inn, Chiner Park, Rajarhat, 24th North Paragan,",
        "Kolkata – 700136",
      ],
      phone: "Tel :040-23222388",
    },
  ];

  interface LocationData {
    id: string;
    title: string;
    name: string;
    address: string[];
    phone: string | null;
    mapUrl: string;
    coordinates?: {
      lat: number;
      lng: number;
    };
  }

  interface LocationsData {
    manufacturingUnits: LocationData[];
    corporateOffices: LocationData[];
    marketingOffices: LocationData[];
  }

  function ManufacturingLocations() {
    const [selectedLocation, setSelectedLocation] = useState<string>("madurai");
    const [selectedCategory, setSelectedCategory] =
      useState<string>("manufacturingUnits");

    const data = locationsData as LocationsData;

    // Find the currently selected location
    const getCurrentLocation = (): LocationData | undefined => {
      for (const category in data) {
        const found = data[category as keyof LocationsData].find(
          (location) => location.id === selectedLocation
        );
        if (found) return found;
      }
      return undefined;
    };

    const currentLocation = getCurrentLocation();

    return (
      <div className="w-full py-6 md:py-12 bg-white">
        <div className="flex flex-col lg:flex-row gap-4 md:gap-8">
          {/* Left side - Location details with responsive height and scrolling */}
          <div className="w-full lg:w-1/3 h-[350px] sm:h-[400px] lg:h-[500px] overflow-hidden flex flex-col">
            {/* Scrollable container with custom thin scrollbar */}
            <div className="overflow-y-auto overflow-x-hidden pr-2 md:pr-4 flex-grow custom-scrollbar">
              {/* Manufacturing Units */}
              <h2 className="text-xl md:text-xl font-semibold text-gray-800 mb-3 md:mb-3 sticky top-0 bg-white z-10 py-2">
                Manufacturing Unit
              </h2>
              <div className="space-y-3 mb-6">
                {data.manufacturingUnits.map((location) => (
                  <div
                    key={location.id}
                    className={`p-3 md:p-6 rounded-md cursor-pointer transition-all ${
                      selectedLocation === location.id
                        ? "bg-gray-200 border-l-4 border-blue-600"
                        : "bg-gray-100 hover:bg-gray-200"
                    }`}
                    onClick={() => {
                      setSelectedLocation(location.id);
                      setSelectedCategory("manufacturingUnits");
                    }}
                  >
                    <h3 className="font-semibold text-gray-800 mb-1 text-sm md:text-base">
                      {location.title}
                    </h3>
                    <p className="font-medium text-gray-700 text-sm md:text-base">
                      {location.name}
                    </p>
                    {location.address.map((line, index) => (
                      <p
                        key={index}
                        className="text-gray-600 text-xs md:text-sm overflow-hidden text-ellipsis"
                      >
                        {line}
                      </p>
                    ))}
                    {location.phone && (
                      <p className="text-gray-700 mt-2 font-medium text-xs md:text-sm">
                        {location.phone}
                      </p>
                    )}
                  </div>
                ))}
              </div>

              {/* Corporate Offices */}
              <h2 className="text-xl md:text-xl font-bold text-gray-800 mb-3 md:mb-3 sticky top-0 bg-white z-10 py-2">
                Corporate Office
              </h2>
              <div className="space-y-3 mb-6">
                {data.corporateOffices.map((location) => (
                  <div
                    key={location.id}
                    className={`p-3 md:p-6 rounded-md cursor-pointer transition-all ${
                      selectedLocation === location.id
                        ? "bg-gray-200 border-l-4 border-blue-600"
                        : "bg-gray-100 hover:bg-gray-200"
                    }`}
                    onClick={() => {
                      setSelectedLocation(location.id);
                      setSelectedCategory("corporateOffices");
                    }}
                  >
                    <h3 className="font-semibold text-gray-800 mb-1 text-sm md:text-base">
                      {location.title}
                    </h3>
                    <p className="font-medium text-gray-700 text-sm md:text-base">
                      {location.name}
                    </p>
                    {location.address.map((line, index) => (
                      <p
                        key={index}
                        className="text-gray-600 text-xs md:text-sm overflow-hidden text-ellipsis"
                      >
                        {line}
                      </p>
                    ))}
                    {location.phone && (
                      <p className="text-gray-700 mt-2 font-medium text-xs md:text-sm">
                        {location.phone}
                      </p>
                    )}
                  </div>
                ))}
              </div>

              {/* Marketing Offices */}
              <h2 className="text-xl md:text-xl font-bold text-gray-800 mb-3 md:mb-3 sticky top-0 bg-white z-10 py-2">
                Marketing Office
              </h2>
              <div className="space-y-3 mb-6">
                {data.marketingOffices.map((location) => (
                  <div
                    key={location.id}
                    className={`p-3 md:p-6 rounded-md cursor-pointer transition-all ${
                      selectedLocation === location.id
                        ? "bg-gray-200 border-l-4 border-blue-600"
                        : "bg-gray-100 hover:bg-gray-200"
                    }`}
                    onClick={() => {
                      setSelectedLocation(location.id);
                      setSelectedCategory("marketingOffices");
                    }}
                  >
                    <h3 className="font-semibold text-gray-800 mb-1 text-sm md:text-base">
                      {location.title}
                    </h3>
                    <p className="font-medium text-gray-700 text-sm md:text-base">
                      {location.name}
                    </p>
                    {location.address.map((line, index) => (
                      <p
                        key={index}
                        className="text-gray-600 text-xs md:text-sm overflow-hidden text-ellipsis"
                      >
                        {line}
                      </p>
                    ))}
                    {location.phone && (
                      <p className="text-gray-700 mt-2 font-medium text-xs md:text-sm">
                        {location.phone}
                      </p>
                    )}
                  </div>
                ))}
              </div>
            </div>
          </div>

          {/* Right side - Map */}
          <div className="w-full lg:w-2/3 mt-4 lg:mt-0">
            <div className="relative h-[300px] sm:h-[400px] lg:h-[500px] overflow-hidden">
              {/* Map iframe */}
              {currentLocation?.mapUrl ? (
                <iframe
                  src={currentLocation.mapUrl}
                  width="100%"
                  height="100%"
                  style={{ border: 0 }}
                  allowFullScreen={false}
                  loading="lazy"
                  title={`Map of ${currentLocation.title}`}
                ></iframe>
              ) : (
                <div className="w-full h-full flex items-center justify-center bg-gray-100">
                  <p className="text-gray-500">Map not available</p>
                </div>
              )}
            </div>
          </div>
        </div>

        {/* Custom scrollbar styles */}
        <style jsx global>{`
          /* Custom scrollbar styling */
          .custom-scrollbar::-webkit-scrollbar {
            width: 6px;
          }

          .custom-scrollbar::-webkit-scrollbar-track {
            background: #f1f1f1;
            border-radius: 10px;
          }

          .custom-scrollbar::-webkit-scrollbar-thumb {
            background: #c1c1c1;
            border-radius: 10px;
          }

          .custom-scrollbar::-webkit-scrollbar-thumb:hover {
            background: #a8a8a8;
          }

          /* For Firefox */
          .custom-scrollbar {
            scrollbar-width: thin;
            scrollbar-color: #c1c1c1 #f1f1f1;
          }
        `}</style>
      </div>
    );
  }

  return (
    <div className="">
      <div className="mb-5">
        <Breadcrumbs />
      </div>
      <div className="relative w-full h-[400px] md:h-[400px] overflow-hidden bg-black mb-[4%]">
        {/* Letterbox style image */}
        <div className="absolute inset-0 flex  h-full items-center justify-center">
          <Image
            src={bannerImage}
            alt="Contact us"
            width={1920}
            height={400}
            className="w-full h-full object-cover"
            priority
          />
        </div>
        <div className="relative z-10 h-full flex items-center justify-center">
          <div className="text-center text-white">
            <h1 className="text-3xl uppercase md:text-4xl font-bold [text-shadow:_0_0_1rem_black]">
              Contact Us
            </h1>
          </div>
        </div>
      </div>
      <div className="mb-[2%]">
        <BoxContainer>
          <div className="grid grid-cols-1 sm:grid-cols-2 lg:grid-cols-4 gap-14">
            {contactOptions.map((option, index) => (
              <ContactOption
                key={index}
                icon={option.icon}
                title={option.title}
                href={option.href}
              />
            ))}
          </div>
        </BoxContainer>
      </div>
      <BoxContainer>
        <ManufacturingLocations />
      </BoxContainer>
      <div className="mb-[2%]">
        <BoxContainer>
          <h2 className="text-3xl font-bold text-tegblue text-center mb-10">
            REGIONAL OFFICES
          </h2>

          <div className="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-3 gap-8">
            {offices.map((office, index) => (
              <div key={index} className="mb-6">
                <h3 className="font-bold text-gray-800 mb-1">
                  {office.region}:
                </h3>
                <h3 className="font-bold text-gray-800 mb-1">
                  {office.officename}:
                </h3>
                {office.address.map((line, lineIndex) => (
                  <p
                    key={lineIndex}
                    className={`text-gray-600 ${
                      lineIndex === 0 ? "font-medium" : ""
                    }`}
                  >
                    {line}
                  </p>
                ))}
                <p className="text-gray-700 mt-1 font-bold">{office.phone}</p>
              </div>
            ))}
          </div>
        </BoxContainer>
      </div>
    </div>
  );
}
