'use client';
import Subheader from '@/components/shared/widget/Subheader';
import { generateYearsArray } from '@/lib/utils';
import Image from 'next/image';
import React, { useEffect, useState } from 'react';

interface FinancialResProps {
  'ir-ar-pdf-name': string;
  year: string;
  'ir-ar-pdf-link': string;
}

const Page = () => {
  const [selectedYear, setSelectedYear] = useState<number>(2024);
  const [financialResults, setFinancialResults] = useState<FinancialResProps[]>(
    []
  );

  useEffect(() => {
    const fetchFinancialResults = async (selectedYear: number) => {
      try {
        const response = await fetch(
          `/api/v1/investor-relations/financial-results?title=financial-results&year=${selectedYear}`
        );
        if (!response.ok) {
          throw new Error('Failed to fetch financial results');
        }
        const data = await response.json();
        setFinancialResults(data?.data);
      } catch (error) {
        console.error(error);
      }
    };
    fetchFinancialResults(selectedYear);
  }, [selectedYear]);
  return (
    <div className='ir-wrapper'>
      <Subheader
        title='Financial Results'
        image='/assets/images/financial-results-banner.webp'
        subtext='We are commited to maintaining our excellent financial records in the years to come, View or Download all our Financial Reports since FY 2009-10'
      />
      <select
        className='w-full text-[#000] text-[14px] px-[12px] py-[8px] mb-5 border-spacing-1 border-[#ccc]'
        onChange={(e) => {
          setSelectedYear(parseInt(e.target.value));
        }}
        value={selectedYear}
      >
        <option value={''}>Select...</option>
        {generateYearsArray(2009).map((year) => {
          return (
            <option key={year} value={year}>
              {year}
            </option>
          );
        })}
      </select>

      <h3>Financial Results {selectedYear}</h3>
      <div className='flex justify-start'>
        {financialResults.length > 0 && (
          <ul className='yearwise-list-pdfs'>
            {financialResults?.map((item, ind) => {
              return (
                <li key={ind} className='ml-2'>
                  <a href={item?.['ir-ar-pdf-link']} target='_blank'>
                    {item?.['ir-ar-pdf-name']}
                  </a>
                </li>
              );
            })}
          </ul>
        )}
        {financialResults.length === 0 && <p>No Data Available</p>}
      </div>
    </div>
  );
};

export default Page;
