'use client';
import Subheader from '@/components/shared/widget/Subheader';
import React, { useEffect, useState } from 'react';
import annualReportData from '@/database/investor-relations/unclaimed-dividend-share.json';
import { generateYearsArray } from '@/lib/utils';

interface annualReportProps {
  'ir-uds-pdf-name': string;
  year: string;
  'ir-uds-pdf-link': string;
}

const Page = () => {
  const [selectedYear, setSelectedYear] = useState<string>('2024');
  const [annualReportResults, setAnnualReportResults] = useState<
    annualReportProps[]
  >([]);

  useEffect(() => {
    if (selectedYear !== '') {
      const filterData = annualReportData?.filter((item) => {
        return item?.year === selectedYear;
      }) as annualReportProps[];
      setAnnualReportResults(filterData);
    }
  }, [selectedYear]);

  return (
    <div className='ir-wrapper'>
      <Subheader
        title='Unclaimed dividend / shares'
        image='/assets/images/annual-report-banner.jpg'
        subtext=''
      />
      <div>
        <h4>
          <strong>Name of the Nodal Officer: Mr Chinmoy Patnaik</strong>
        </h4>
        <address>
          Contact Details: TVS Srichakra Ltd., <br />
          Perumalpatti Road, Vellaripatti Village,
          <br />
          Melur Taluk, Madurai 625122
          <br />
          Telephone – 0452 2443300
        </address>
      </div>
      <select
        className='w-full text-[#000] text-[14px] px-[12px] py-[8px] mb-5 border-spacing-1 border-[#ccc]'
        onChange={(e) => {
          setSelectedYear(e.target.value);
        }}
        value={selectedYear}
      >
        <option value={''}>Select...</option>
        {generateYearsArray(2017).map((year) => {
          return (
            <option key={year} value={year}>
              {year}
            </option>
          );
        })}
      </select>
      <h3>Unclaimed dividend / shares {selectedYear}</h3>
      {annualReportResults.length === 0 && 'No Data available'}
      {annualReportResults.length > 0 && (
        <ul className='yearwise-list-pdfs'>
          {annualReportResults?.map((items: annualReportProps, ind: number) => {
            return (
              <li key={ind}>
                <a href={items?.['ir-uds-pdf-link']}>
                  {items?.['ir-uds-pdf-name']}
                </a>
              </li>
            );
          })}
        </ul>
      )}
    </div>
  );
};

export default Page;
