'use client';
import Subheader from '@/components/shared/widget/Subheader';
import React, { useEffect, useState } from 'react';
import annualReportData from '@/database/investor-relations/voting-results.json';
import { generateYearRange } from '@/lib/utils';

interface annualReportProps {
  'ir-voting-results-name': string;
  year: string;
  'ir-voting-results-link': string;
}

const Page = () => {
  const [selectedYear, setSelectedYear] = useState<string>('2023-24');
  const [annualReportResults, setAnnualReportResults] = useState<
    annualReportProps[]
  >([]);

  useEffect(() => {
    if (selectedYear !== '') {
      const filterData = annualReportData?.filter((item) => {
        return item?.year === selectedYear;
      }) as annualReportProps[];
      setAnnualReportResults(filterData);
    }
  }, [selectedYear]);

  return (
    <div className='ir-wrapper'>
      <Subheader
        title='Voting results'
        image='/assets/images/annual-report-banner.jpg'
        subtext='We are commited to maintaining our excellent financial records in the years to come, View or Download all our Annual Reports since FY 2008-09'
      />
      <select
        className='w-full text-[#000] text-[14px] px-[10px] py-[5px] mb-5 border-spacing-1 border-[]'
        onChange={(e) => {
          setSelectedYear(e.target.value);
        }}
        value={selectedYear}
      >
        <option value={''}>Select...</option>
        {generateYearRange(2018, 2023).map((year) => {
          return (
            <option key={year} value={year}>
              {year}
            </option>
          );
        })}
      </select>
      <h3>Voting results {selectedYear}</h3>
      {annualReportResults.length === 0 && 'No Data available'}
      {annualReportResults.length > 0 && (
        <ul className='yearwise-list-pdfs'>
          {annualReportResults?.map((items: annualReportProps, ind: number) => {
            return (
              <li key={ind}>
                <a href={items?.['ir-voting-results-link']}>
                  {items?.['ir-voting-results-name']}
                </a>
              </li>
            );
          })}
        </ul>
      )}
    </div>
  );
};

export default Page;
