'use client';
import { useComparisonStore } from '@/store/useComparisonStore';
import {
  faCartShopping,
  faTrashCan,
  faXmark,
} from '@fortawesome/free-solid-svg-icons';
import { FontAwesomeIcon } from '@fortawesome/react-fontawesome';
import React from 'react';
import Image from 'next/image';
import Link from 'next/link';
import productAttributeData from '@/database/products/product-attributes.json';
import { SecureHTMLRenderer } from '@/components/shared/secure-html-renderer';

const Page = () => {
  const { compareProducts } = useComparisonStore();
  return (
    <div className='w-full'>
      <header className='w-full flex justify-between items-center mb-5'>
        <h1 className='text-[36px] font-semibold mt-5 mb-2'>
          Compare Products
        </h1>
        {compareProducts.length > 0 && <ClearCompareProducts />}
      </header>
      {compareProducts.length === 0 && (
        <p className='mt-5'>
          No products to compare. Go to{' '}
          <Link
            href='/products/two-wheeler'
            className='text-tegblue font-semibold'
          >
            products
          </Link>{' '}
          page to add products to the comparison.
        </p>
      )}
      {compareProducts.length > 0 && (
        <>
          <div className='w-full'>
            <table className='teg-compare-table'>
              <tbody className='teg-compare-table-body'>
                <tr className='teg-compare-table-row'>
                  <th className='teg-compare-table-heading'>Items Compared</th>
                  {compareProducts?.map((item, ind) => {
                    return (
                      <td
                        key={ind}
                        className='teg-compare-table-cell teg-compare-item'
                      >
                        <RemoveBtn id={item?.id} />
                      </td>
                    );
                  })}
                </tr>
                <tr className='teg-compare-table-row'>
                  <th className='teg-compare-table-heading'>Product Image</th>
                  {compareProducts?.map((item, ind) => {
                    const imageUrl = item?.imageURL?.split('|');
                    return (
                      <td
                        key={ind}
                        className='teg-compare-table-cell teg-compare-item'
                      >
                        <Image
                          src={imageUrl[0]}
                          width={80}
                          height={80}
                          alt={item?.title}
                          // style={{ width: '100%' }}
                          className='w-[180px] h-[180px] m-auto'
                        />
                      </td>
                    );
                  })}
                </tr>
                <tr className='teg-compare-table-row'>
                  <th className='teg-compare-table-heading'>Product Name</th>
                  {compareProducts?.map((item, ind) => {
                    return (
                      <td
                        key={ind}
                        className='teg-compare-table-cell teg-compare-item'
                      >
                        <span className='text-tegred uppercase text-[14px] font-semibold'>
                          {item?.title}
                        </span>
                      </td>
                    );
                  })}
                </tr>
                <tr className='teg-compare-table-row'>
                  <th className='teg-compare-table-heading'>Price</th>
                  {compareProducts?.map((item, ind) => {
                    return (
                      <td
                        key={ind}
                        className='teg-compare-table-cell teg-compare-item'
                      >
                        <bdi className='text-tegblue text-[18px] font-semibold'>
                          ₹{item?.price}
                        </bdi>
                      </td>
                    );
                  })}
                </tr>
                <tr className='teg-compare-table-row'>
                  <th className='teg-compare-table-heading'>Category</th>
                  {compareProducts?.map((item, ind) => {
                    return (
                      <td
                        key={ind}
                        className='teg-compare-table-cell teg-compare-item'
                      >
                        <span className='text-tegblue'>
                          {item?.productCategories}
                        </span>
                      </td>
                    );
                  })}
                </tr>
                <tr className='teg-compare-table-row'>
                  <th className='teg-compare-table-heading'>Tubing</th>
                  {compareProducts?.map((item, ind) => {
                    const attributes = productAttributeData?.find(
                      (attrItem) => {
                        return attrItem?.id === item?.id;
                      }
                    );
                    return (
                      <td
                        key={ind}
                        className='teg-compare-table-cell teg-compare-item'
                      >
                        <span>{attributes?.attrValue1}</span>
                      </td>
                    );
                  })}
                </tr>
                <tr className='teg-compare-table-row'>
                  <th className='teg-compare-table-heading'>wheel-position</th>
                  {compareProducts?.map((item, ind) => {
                    return (
                      <td
                        key={ind}
                        className='teg-compare-table-cell teg-compare-item'
                      >
                        <span>{item?.wheelPosition}</span>
                      </td>
                    );
                  })}
                </tr>
                <tr className='teg-compare-table-row'>
                  <th className='teg-compare-table-heading'>Section width</th>
                  {compareProducts?.map((item, ind) => {
                    const attributes = productAttributeData?.find(
                      (attrItem) => {
                        return attrItem?.id === item?.id;
                      }
                    );
                    return (
                      <td
                        key={ind}
                        className='teg-compare-table-cell teg-compare-item'
                      >
                        <span>{attributes?.attrValue3}</span>
                      </td>
                    );
                  })}
                </tr>
                <tr className='teg-compare-table-row'>
                  <th className='teg-compare-table-heading'>Aspect Ratio</th>
                  {compareProducts?.map((item, ind) => {
                    const attributes = productAttributeData?.find(
                      (attrItem) => {
                        return attrItem?.id === item?.id;
                      }
                    );
                    return (
                      <td
                        key={ind}
                        className='teg-compare-table-cell teg-compare-item'
                      >
                        <span>{attributes?.attrValue4}</span>
                      </td>
                    );
                  })}
                </tr>
                <tr className='teg-compare-table-row'>
                  <th className='teg-compare-table-heading'>Rim Diameter</th>
                  {compareProducts?.map((item, ind) => {
                    const attributes = productAttributeData?.find(
                      (attrItem) => {
                        return attrItem?.id === item?.id;
                      }
                    );
                    return (
                      <td
                        key={ind}
                        className='teg-compare-table-cell teg-compare-item'
                      >
                        <span>
                          {attributes?.attrValue5 === ''
                            ? '-'
                            : attributes?.attrValue5}
                        </span>
                      </td>
                    );
                  })}
                </tr>
                <tr className='teg-compare-table-row'>
                  <th className='teg-compare-table-heading'>Load Index</th>
                  {compareProducts?.map((item, ind) => {
                    const attributes = productAttributeData?.find(
                      (attrItem) => {
                        return attrItem?.id === item?.id;
                      }
                    );
                    return (
                      <td
                        key={ind}
                        className='teg-compare-table-cell teg-compare-item'
                      >
                        <span>
                          {attributes?.attrValue6 === ''
                            ? '-'
                            : attributes?.attrValue6}
                        </span>
                      </td>
                    );
                  })}
                </tr>
                <tr className='teg-compare-table-row'>
                  <th className='teg-compare-table-heading'>Speed rating</th>
                  {compareProducts?.map((item, ind) => {
                    const attributes = productAttributeData?.find(
                      (attrItem) => {
                        return attrItem?.id === item?.id;
                      }
                    );
                    return (
                      <td
                        key={ind}
                        className='teg-compare-table-cell teg-compare-item'
                      >
                        <span>
                          {attributes?.attrValue7 === ''
                            ? '-'
                            : attributes?.attrValue7}
                        </span>
                      </td>
                    );
                  })}
                </tr>
                <tr className='teg-compare-table-row'>
                  <th className='teg-compare-table-heading align-top'>
                    Product Details
                  </th>
                  {compareProducts?.map((item, ind) => {
                    return (
                      <td
                        key={ind}
                        className='teg-compare-table-cell teg-compare-item align-top'
                      >
                        <div className='teg-description-rich-text'>
                          <SecureHTMLRenderer html={item?.content} />
                        </div>
                      </td>
                    );
                  })}
                </tr>
                <tr className='teg-compare-table-row'>
                  <th className='teg-compare-table-heading'>Purchase</th>
                  {compareProducts?.map((item, ind) => {
                    return (
                      <td
                        key={ind}
                        className='teg-compare-table-cell teg-compare-item'
                      >
                        <AddToCart />
                      </td>
                    );
                  })}
                </tr>
              </tbody>
            </table>
          </div>
        </>
      )}
    </div>
  );
};

const RemoveBtn = ({ id }: { id: string }) => {
  const { removeProduct } = useComparisonStore();
  return (
    <button
      className='teg-compare-item-remove-button'
      onClick={() => {
        removeProduct(id);
      }}
    >
      <FontAwesomeIcon icon={faTrashCan} />
      <span className='text'>Remove</span>
    </button>
  );
};
const AddToCart = () => {
  return (
    <button className='bg-tegred text-white px-3 py-2 flex gap-2 justify-center items-center m-auto'>
      <FontAwesomeIcon icon={faCartShopping} />
      <span className='text'>Add to cart</span>
    </button>
  );
};
const ClearCompareProducts = () => {
  const { clearComparison } = useComparisonStore();
  return (
    <button
      className='bg-tegblue text-white px-3 py-2 flex gap-2 justify-center items-center'
      onClick={clearComparison}
    >
      <FontAwesomeIcon icon={faXmark} />
      <span className='text'>Clear products</span>
    </button>
  );
};

export default Page;
