"use client";
import Image from "next/image";
import Breadcrumbs from "@/components/shared/Breadcrumbs";
import BoxContainer from "@/components/shared/box-container";
import { faQuoteLeft } from "@fortawesome/free-solid-svg-icons";

import { ChevronDown, ChevronUp } from "lucide-react";
import { useRef, useState } from "react";
import { FontAwesomeIcon } from "@fortawesome/react-fontawesome";

interface AccordionItem {
  id: string;
  title: string;
  content: string;
  isOpen: boolean;
}

export default function ResearchFacilities() {
  const [accordionItems, setAccordionItems] = useState<AccordionItem[]>([
    {
      id: "item1",
      title: "Advanced Tyre Technology development at Europe",
      content:
        "Eurogrip extends tyre tech research partnership ... which centres upon research projects that advance tyre-related technological innovation.",
      isOpen: true,
    },
    {
      id: "item2",
      title: "State of the art R&D Centre and proving grounds in Madurai",
      content:
        "Our state-of-the-art R&D facility in Madurai is equipped with the latest technology for tire testing and development.",
      isOpen: false,
    },
    {
      id: "item3",
      title:
        "Japanese & European experts for technology, product and process development",
      content:
        "We collaborate with leading experts from Japan and Europe to enhance our product development and manufacturing processes.",
      isOpen: false,
    },
    {
      id: "item4",
      title: "Jury of Japanese, European & Indian test riders",
      content:
        "Our tires undergo rigorous testing by a diverse panel of experienced test riders from Japan, Europe, and India.",
      isOpen: false,
    },
    {
      id: "item5",
      title: "Advanced tyre modelling using predictive technology",
      content:
        "We utilize cutting-edge predictive modeling technology to optimize tire performance before physical prototyping.",
      isOpen: false,
    },
    {
      id: "item6",
      title: "International expertise in material science research",
      content:
        "Our material science research benefits from international expertise to develop innovative compounds for superior tire performance.",
      isOpen: false,
    },
  ]);
  const contentRefs = useRef<any>([]);
  function PassionateSection() {
    const videoRef = useRef<any>(null);

    return (
      <div
        className="relative w-full bg-black py-16 mb-[4%]"
        style={{
          backgroundImage:
            'url("https://tvseurogrip.com/wp-content/uploads/2022/01/technology-cto-background1.jpg")',
          backgroundPosition: "top center",
          backgroundRepeat: "no-repeat",
          backgroundSize: "cover",
        }}
      >
        <BoxContainer>
          <div className="container mx-auto px-4 relative z-10">
            {/* Heading */}
            <h2 className="text-white text-3xl md:text-4xl font-semibold text-center mb-10">
              WE ARE PASSIONATE ABOUT TYRES
            </h2>

            {/* Video section */}
            <div className="max-w-[40rem] mx-auto mb-10">
              <div className="relative aspect-video">
                <iframe
                  ref={videoRef}
                  className="absolute inset-0 w-full h-full"
                  src="https://www.youtube.com/embed/bsMaLMBqaB4?controls=1&rel=0&playsinline=0&modestbranding=0&cc_load_policy=0&autoplay=0&enablejsapi=1&origin=https%3A%2F%2Ftvseurogrip.com&widgetid=3&forigin=https%3A%2F%2Ftvseurogrip.com%2Fresearch-facilities%2F&aoriginsup=1&gporigin=https%3A%2F%2Ftvseurogrip.com%2Fjourney-of-tvs%2F&vf=1"
                  title="National Technology Day"
                  allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture"
                  allowFullScreen
                ></iframe>
              </div>
            </div>

            {/* Two column text section */}
            <div className="grid grid-cols-1 md:grid-cols-2 gap-8 md:gap-16 text-white">
              {/* Left column */}
              <div className="space-y-4">
                <div className="flex items-center">
                  <span className="text-6xl text-gray-400 leading-none mr-5">
                    <FontAwesomeIcon icon={faQuoteLeft} />
                  </span>
                  <h3 className="text-xl md:text-2xl font-semibold opacity-50">
                    Message from the CTO
                  </h3>
                </div>
                <p className="text-sm md:text-base text-gray-200 font-light leading-relaxed">
                  Eurogrip tyres are backed by over 3 decades of bike tyre
                  design and manufacturing expertise. At our state-of-the art
                  research centre, a team of over 75 experts and international
                  specialists, research the best materials, designs,
                  technologies and processes to create high quality products.
                  Combining our R&D team’s in-depth knowledge of Indian road
                  conditions with international expertise, we develop advanced
                  tyre models and superior tyre designs. Our products are put
                  through a million cycles of durability tests meeting global
                  certification standards and are tested by experts and
                  professional racers on Indian and international tracks.
                </p>
                <p className="text-sm md:text-base text-gray-200 font-light leading-relaxed">
                  Every product we make comes with our quality promise, to
                  deliver a fulfilling riding experience.
                </p>
                <h2 className="text-2xl font-semibold mt-10">
                  Sivaramakrishnan V
                </h2>
                <small className="text-gray-500">
                  Chief Technology Officer
                </small>
              </div>

              {/* Right column */}
              <div className="space-y-4">
                <div className="flex items-center">
                  <span className="text-6xl text-gray-400 leading-none mr-5">
                    <FontAwesomeIcon icon={faQuoteLeft} />
                  </span>
                  <h3 className="text-xl md:text-2xl font-semibold opacity-50">
                    Taking a global perspective
                  </h3>
                </div>
                <p className="text-sm md:text-base text-gray-200 font-light leading-relaxed">
                  A global product development centre with a team of two-wheeler
                  tyre specialists was set up in Milan, Italy in 2019 From the
                  core of the EU market, we study new market trends and riders’
                  needs to passionately develop new products aimed at Indian and
                  international customers alike. Our compounding, design and
                  testing experts focus on raising the bar on the performance of
                  our products, to meet the evolving, challenging and increasing
                  demand of new age two-wheelers. Top-end materials,
                  state-of-the-art digital design and the ultimate outdoor
                  testing methodologies are the tools that are driving Eurogrip
                  to take on the challenges of the global market.
                </p>
                <h2 className="text-2xl font-semibold mt-0">
                  Silvio Montanari
                </h2>
                <small className="text-gray-500">R&D Operations, Milan</small>
              </div>
            </div>
          </div>
        </BoxContainer>
      </div>
    );
  }
  const toggleAccordion = (id: string) => {
    setAccordionItems(
      accordionItems.map((item) =>
        item.id === id
          ? { ...item, isOpen: !item.isOpen }
          : { ...item, isOpen: false }
      )
    );
  };

  function FutureBanner() {
    const [isVisible, setIsVisible] = useState(true);

    return (
      <div className="relative w-full h-[500px] md:h-[500px] lg:h-[600px] overflow-hidden bg-black">
        {/* Background with overlay */}
        <div className=" z-10"></div>

        {/* Main image as background */}
        <div className="absolute inset-0 z-0 flex items-center justify-center">
          <div
            className={`relative w-full h-full transition-all duration-1500 delay-500 ${
              isVisible ? "opacity-100 scale-100" : "opacity-0 scale-90"
            }`}
          >
            <Image
              src="https://tvseurogrip.com/wp-content/uploads/2021/12/research-facilities-banner-webres.jpg"
              alt="Futuristic tire technology"
              fill
              className="object-cover"
              priority
            />
          </div>
        </div>

        {/* Content overlay */}
        <div className="relative z-20 h-full flex flex-col items-center justify-between py-6 md:py-12 px-4 text-white">
          {/* Heading section */}
          <div className="text-center mb-2 md:mb-4 mt-4 md:mt-8">
            <h1
              className={`text-3xl sm:text-4xl md:text-3xl font-semibold mb-2 transition-all duration-1000 ${
                isVisible ? "opacity-100" : "opacity-0 translate-y-10"
              }`}
            >
              SHAPING THE FUTURE
            </h1>
            <p
              className={`text-sm sm:text-base md:text-xl text-gray-200 transition-all -mt-3 duration-1000 delay-300 ${
                isVisible ? "opacity-100" : "opacity-0 translate-y-10"
              }`}
            >
              Designed Globally, Manufactured in India, Tested & Sold Worldwide
            </p>
          </div>

          {/* Spacer to push features to bottom */}
          <div className="flex-grow"></div>

          {/* Feature points */}
          <div className="w-full grid grid-cols-1 sm:grid-cols-3 gap-4 mt-2 md:mt-4 mb-6 md:mb-10">
            {[
              { icon: "grid", title: "Designed for Grip" },
              { icon: "droplet", title: "Superior Mileage" },
              { icon: "road", title: "Excellent Durability" },
            ].map((feature, index) => (
              <div
                key={feature.title}
                className={`flex flex-col items-center transition-all duration-1000 ${
                  isVisible
                    ? "opacity-100 translate-y-0"
                    : "opacity-0 translate-y-10"
                }`}
                style={{ transitionDelay: `${800 + index * 200}ms` }}
              >
                <div className="w-8 h-8 md:w-10 md:h-10 border border-white/50 flex items-center justify-center mb-2 md:mb-3 bg-black/40 backdrop-blur-sm hover:scale-150">
                  {feature.icon === "grid" && (
                    <svg
                      xmlns="http://www.w3.org/2000/svg"
                      width="16"
                      height="16"
                      viewBox="0 0 24 24"
                      fill="none"
                      stroke="currentColor"
                      strokeWidth="2"
                      strokeLinecap="round"
                      strokeLinejoin="round"
                      className="md:w-5 md:h-5"
                    >
                      <rect
                        x="3"
                        y="3"
                        width="18"
                        height="18"
                        rx="2"
                        ry="2"
                      ></rect>
                      <line x1="3" y1="9" x2="21" y2="9"></line>
                      <line x1="3" y1="15" x2="21" y2="15"></line>
                      <line x1="9" y1="3" x2="9" y2="21"></line>
                      <line x1="15" y1="3" x2="15" y2="21"></line>
                    </svg>
                  )}
                  {feature.icon === "droplet" && (
                    <svg
                      xmlns="http://www.w3.org/2000/svg"
                      width="16"
                      height="16"
                      viewBox="0 0 24 24"
                      fill="none"
                      stroke="currentColor"
                      strokeWidth="2"
                      strokeLinecap="round"
                      strokeLinejoin="round"
                      className="md:w-5 md:h-5"
                    >
                      <path d="M12 2.69l5.66 5.66a8 8 0 1 1-11.31 0z"></path>
                    </svg>
                  )}
                  {feature.icon === "road" && (
                    <svg
                      xmlns="http://www.w3.org/2000/svg"
                      width="16"
                      height="16"
                      viewBox="0 0 24 24"
                      fill="none"
                      stroke="currentColor"
                      strokeWidth="2"
                      strokeLinecap="round"
                      strokeLinejoin="round"
                      className="md:w-5 md:h-5"
                    >
                      <path d="M18 6H5a2 2 0 0 0-2 2v9a2 2 0 0 0 2 2h13a2 2 0 0 0 2-2V8a2 2 0 0 0-2-2z"></path>
                      <path d="M6 12h12"></path>
                      <path d="M8 9h8"></path>
                      <path d="M9 15h6"></path>
                    </svg>
                  )}
                </div>
                <p className="text-center text-xs sm:text-sm md:text-base font-medium bg-black/40 px-2 py-1 backdrop-blur-sm rounded">
                  {feature.title}
                </p>
              </div>
            ))}
          </div>
        </div>
      </div>
    );
  }

  return (
    <div className="">
      <div className="mb-5">
        <Breadcrumbs />
      </div>
      <div className="">
        <FutureBanner />
      </div>

      <BoxContainer>
        <div className="flex flex-col md:flex-row gap-8 my-[8%]">
          {/* Video section */}
          <div className="w-full md:w-1/2">
            <div
              className="relative overflow-hidden"
              style={{ minHeight: "300px" }}
            >
              <div className="absolute inset-0 z-0">
                <Image
                  src="https://tvseurogrip.com/wp-content/uploads/2022/01/research-facilities-middle-banner-webres-rev.jpg"
                  alt="Research facilties"
                  fill
                  className="object-cover"
                  priority
                />
              </div>

              {/* Video container */}
              <div className="relative z-10 flex items-center justify-center w-full h-full p-16 md:p-20">
                <div className="relative w-full max-w-[560px] border-4 border-white overflow-hidden shadow-lg">
                  {/* YouTube embed */}
                  <div className="relative aspect-video">
                    <iframe
                      className="absolute inset-0 w-full h-full"
                      src="https://www.youtube.com/embed/uHs8PyHl38w?controls=1&rel=0&playsinline=0&modestbranding=0&cc_load_policy=0&autoplay=0&enablejsapi=1&origin=https%3A%2F%2Ftvseurogrip.com&widgetid=1&forigin=https%3A%2F%2Ftvseurogrip.com%2Fresearch-facilities%2F&aoriginsup=1&gporigin=https%3A%2F%2Ftvseurogrip.com%2Fjourney-of-tvs%2F&vf=1" // Replace with actual video ID
                      title="EUROGRIP STEEL RADIALS"
                      allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture"
                      allowFullScreen
                    ></iframe>
                  </div>
                </div>
              </div>
            </div>
          </div>

          {/* Accordion section */}
          <div className="w-full md:w-1/2">
            <div className="space-y-2">
              {accordionItems.map((item, index) => (
                <div key={item.id} className="overflow-hidden">
                  <button
                    className="w-full flex items-center justify-between px-4 py-3 text-left"
                    onClick={() => toggleAccordion(item.id)}
                    aria-expanded={item.isOpen}
                  >
                    <div className="flex items-center">
                      <span className="text-tegblue mr-2">▶</span>
                      <h3 className="text-tegblue font-medium text-wrap">
                        {item.title}
                      </h3>
                    </div>
                    <span className="text-tegblue transition-transform duration-300">
                      {item.isOpen ? (
                        <ChevronUp size={16} />
                      ) : (
                        <ChevronDown size={16} />
                      )}
                    </span>
                  </button>

                  {item.isOpen && (
                    <div
                      className="overflow-hidden transition-all duration-300 ease-in-out px-4 py-2 text-md font-light  text-gray-500"
                      style={{
                        maxHeight: item.isOpen ? "200px" : "0",
                        opacity: item.isOpen ? 1 : 0,
                      }}
                    >
                      <div
                        className="px-3  text-gray-300"
                        ref={(el: any) => (contentRefs.current[index] = el)}
                      >
                        <p>{item.content}</p>
                      </div>
                    </div>
                  )}
                </div>
              ))}
            </div>
          </div>
        </div>
      </BoxContainer>
      <PassionateSection />
    </div>
  );
}
