"use client";
import Image from "next/image";
import Breadcrumbs from "@/components/shared/Breadcrumbs";
import BoxContainer from "@/components/shared/box-container";
import { Wrench, LifeBuoy, Clock, BookOpen } from "lucide-react";
import {
  faCheckDouble,
  faLifeRing,
  faSmog,
  faStroopwafel,
  faCompactDisc,
  faBiking,
  faSearch,
  faShoppingCart,
  faWrench,
  faBook,
  faClock,
  faMapMarkerAlt,
  faAddressCard,
  faCreditCard,
  faDoorOpen,
  faBookReader,
  faInfo,
  faBahai,
  faEquals,
  faDiceD20,
  faHandsWash,
  faSpinner,
  faUserCircle,
} from "@fortawesome/free-solid-svg-icons";
import { FontAwesomeIcon } from "@fortawesome/react-fontawesome";
import { cn } from "@/lib/utils";
import { useEffect, useRef } from "react";

export default function UserJourney() {
  const journeyRefs = useRef<{ [key: string]: HTMLDivElement | null }>({});

  const bestChoiceImage =
    "https://tvseurogrip.com/wp-content/uploads/2021/10/teg-single-product-page-technology-BG.jpg";
  const bestChoiceBadge =
    "	https://tvseurogrip.com/wp-content/uploads/2022/01/why-tvseurogrip-Best-choice.png";

  const registrationSteps = [
    {
      step: "Step 1:",
      content: "Navigate to Header Menu > Two Wheelers > Warranty Registration",
    },
    {
      step: "Step 2:",
      content: "Enter your name and valid mobile no which has Whatsapp",
    },
    {
      step: "Step 3:",
      content:
        "Validate your mobile number with OTP verfication received thru SMS",
    },
    {
      step: "Step 4:",
      content: "Fill in full product details & Click on Submit button",
    },
  ];

  function TyreCheck() {
    const tyreChecks = [
      {
        image:
          "https://tvseurogrip.com/wp-content/uploads/2021/12/teg-tyre-guide-blog-readatyre-1024x576.jpg",
        title:
          "Your old Tyre Width (Section Width & Aspect Ratio), Wheel/ Rim Diameter & Speed rating",
        imageAlt: "Tyre width and specifications",
      },
      {
        image:
          "https://tvseurogrip.com/wp-content/uploads/2022/03/tyre-guide-1-1-1024x576.jpg",
        title: "Is your tread depth less than 3mm ?",
        imageAlt: "Coin measuring tread depth",
      },
      {
        image:
          "https://tvseurogrip.com/wp-content/uploads/2022/03/tyre-guide-2-1024x576.jpg",
        title: "Are there are any visible cracks in the sidewall ?",
        imageAlt: "Sidewall cracks in tyre",
      },
      {
        image:
          "https://tvseurogrip.com/wp-content/uploads/2022/03/tyre-guide-3-1024x576.jpg",
        title: "Are there bulges or blisters appear on the tyre ?",
        imageAlt: "Bulges on tyre surface",
      },
      {
        image:
          "https://tvseurogrip.com/wp-content/uploads/2022/03/tyre-guide-4-1024x576.jpg",
        title: "Does your vehicle produces a vibration while driving ?",
        imageAlt: "Motorcycle on road",
      },
      {
        image:
          "https://tvseurogrip.com/wp-content/uploads/2022/03/tyre-guide-5-1024x576.jpg",
        title:
          "Are there frequent punctures & air pressure dropping unexpectedly ?",
        imageAlt: "Tyre with puncture",
      },
    ];

    const buttons = [
      {
        icon: <FontAwesomeIcon icon={faWrench} />,
        hoverIcon: <FontAwesomeIcon icon={faBook} />,
        label: "Tyre Repair",
        hoverLabel: "Tyre Guide",
        href: "/tyre-repair",
      },
      {
        icon: <FontAwesomeIcon icon={faLifeRing} />,
        hoverIcon: <FontAwesomeIcon icon={faBook} />,
        label: "Tyre Size",
        hoverLabel: "Tyre Guide",
        href: "/tyre-size",
      },
      {
        icon: <FontAwesomeIcon icon={faClock} />,
        hoverIcon: <FontAwesomeIcon icon={faBook} />,
        label: "Need Change",
        hoverLabel: "Tyre Guide",
        href: "/tyre-change",
      },
    ];

    return (
      <div
        className="container mx-auto px-4 py-12"
        id="userjourney1"
        ref={(el:any) => (journeyRefs.current['userjourney1'] = el)}
      >
        <h1 className="text-center text-2xl md:text-3xl lg:text-3xl font-semibold text-tegblue mb-12">
          HOW DO I CHECK MY TYRE?
        </h1>

        <div className="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-3 gap-x-4 gap-y-12 mb-12">
          {tyreChecks.map((check, index) => (
            <div
              key={index}
              className="flex flex-col items-center"
              title={check.title}
            >
              <div className="relative w-48 h-48 md:w-56 md:h-56 lg:w-64 lg:h-64 rounded-full overflow-hidden mb-4 border-4 border-gray-100 shadow-md">
                <Image
                  src={check.image || "/placeholder.svg"}
                  alt={check.imageAlt}
                  fill
                  className="object-cover"
                />
              </div>
              <p className="text-center font-semibold text-sm md:text-base text-gray-500 max-w-xs">
                {check.title}
              </p>
            </div>
          ))}
        </div>

        {/* Buttons row */}
        <div className="grid grid-cols-1 md:grid-cols-3 gap-4 mt-8">
          {buttons.map((button, index) => (
            <div key={index} className="flex justify-center">
              <a
                href={button.href}
                className="relative overflow-hidden bg-tegblue text-white rounded-md w-full max-w-xs py-3 px-6 flex items-center justify-center group transition-all duration-300"
              >
                {/* Red background that slides from bottom-right to top-left on hover */}
                <span className="absolute inset-0 bg-red-600 origin-bottom-right translate-x-full translate-y-full rotate-45 scale-0 group-hover:scale-[2.5] group-hover:translate-x-0 group-hover:translate-y-0 group-hover:rotate-0 transition-all duration-500 ease-in-out"></span>

                {/* Default state */}
                <div className="flex items-center justify-center space-x-2 relative z-10 w-full transition-all duration-300">
                  <span className="group-hover:opacity-0 transition-opacity duration-300 flex items-center">
                    {button.icon}
                    <span className="ml-2">{button.label}</span>
                  </span>

                  {/* Hover state */}
                  <span className="absolute inset-0 flex items-center justify-center opacity-0 group-hover:opacity-100 transition-opacity duration-300">
                    {button.hoverIcon}
                    <span className="ml-2">{button.hoverLabel}</span>
                  </span>
                </div>
              </a>
            </div>
          ))}
        </div>
      </div>
    );
  }

  function TyreSelect() {
    const tyreSelectionGuides = [
      {
        icon: (
          <FontAwesomeIcon
            icon={faCheckDouble}
            size="2x"
            className="text-white group-hover:text-yellow-300 transition-colors duration-300"
          />
        ),
        description: "Vehicle Manufacturer's Prescribed",
        title: "EXACT TYRE SIZE",
      },
      {
        icon: (
          <FontAwesomeIcon
            icon={faLifeRing}
            size="2x"
            className="text-white group-hover:text-yellow-300 transition-colors duration-300"
          />
        ),
        description: "Also check the right",
        title: "SPEED INDEX & LOAD CAPACITY",
      },
      {
        icon: (
          <FontAwesomeIcon
            icon={faSmog}
            size="2x"
            className="text-white group-hover:text-yellow-300 transition-colors duration-300"
          />
        ),
        description: "The factors to consider are",
        title: "TOUGHNESS, PERFORMANCE, SEASON & TYPE OF ROADS",
      },
      {
        icon: (
          <FontAwesomeIcon
            icon={faStroopwafel}
            size="2x"
            className="text-white group-hover:text-yellow-300 transition-colors duration-300"
          />
        ),
        description: "Different tread designs for tyres",
        title: "SYMMETRICAL / ASYMMETRICAL / UNIDIRECTIONAL",
      },
      {
        icon: (
          <FontAwesomeIcon
            icon={faCompactDisc}
            size="2x"
            className="text-white group-hover:text-yellow-300 transition-colors duration-300"
          />
        ),
        description: "Select between",
        title: "TUBULAR TYRES OR TUBELESS TYRES",
      },
      {
        icon: (
          <FontAwesomeIcon
            icon={faBiking}
            size="2x"
            className="text-white group-hover:text-yellow-300 transition-colors duration-300"
          />
        ),
        description: "Choose the right tyre construction",
        title: "BIAS FOR HEAVY DUTY & RADIALS FOR PERFORMANCE",
      },
    ];

    return (
      <div className="bg-gray-100 py-12 px-4 my-[4%]" id="userjourney2">
        <div className="container mx-auto">
          <h1 className="text-center text-3xl md:text-4xl font-semibold text-tegblue mb-12">
            HOW DO I SELECT MY TYRE?
          </h1>

          <div className="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-3 gap-8 mb-10">
            {tyreSelectionGuides.map((guide, index) => (
              <div
                key={index}
                className="flex flex-col items-center text-center p-6 rounded-lg transition-all duration-300 bg-transparent hover:shadow-[0_0_15px_rgba(0,0,0,0.3)]"
              >
                <div className="bg-tegblue rounded-full p-5 mb-4 w-20 h-20 flex items-center justify-center shadow-md hover:scale-105 transition-all duration-300 group">
                  {guide.icon}
                </div>
                <p className="text-gray-600 mb-2">{guide.description}</p>
                <h3 className="text-tegblue  text-lg md:text-2xl">
                  {guide.title}
                </h3>
              </div>
            ))}
          </div>

          {/* Default state */}
          <div className="flex justify-center">
            <a
              href="https://tvseurogrip.com/2022/04/15/how-to-select-a-two-wheeler-tyre/"
              target="_blank"
              className="relative overflow-hidden bg-tegblue text-white rounded-md w-full max-w-xs py-3 px-6 flex items-center justify-center group transition-all duration-300"
              rel="noreferrer"
            >
              {/* Red background that slides from bottom-right to top-left on hover */}
              <span className="absolute inset-0 bg-red-600 origin-bottom-right translate-x-full translate-y-full rotate-45 scale-0 group-hover:scale-[2.5] group-hover:translate-x-0 group-hover:translate-y-0 group-hover:rotate-0 transition-all duration-500 ease-in-out"></span>

              {/* Default state */}
              <div className="flex items-center justify-center space-x-2 relative z-10 transition-all duration-300 w-full">
                <span className="group-hover:opacity-0 transition-opacity duration-300 flex items-center">
                  <FontAwesomeIcon icon={faShoppingCart} className="mr-2" />
                  <span>Read More</span>
                </span>

                {/* Hover state */}
                <span className="absolute inset-0 flex items-center justify-center opacity-0 group-hover:opacity-100 transition-opacity duration-300">
                  <FontAwesomeIcon icon={faSearch} className="mr-2" />
                  <span>Tyre Guide</span>
                </span>
              </div>
            </a>
          </div>
        </div>
      </div>
    );
  }

  function TyreBuyOnline() {
    const buyingSteps = [
      {
        icon: (
          <FontAwesomeIcon
            icon={faBiking}
            size="2x"
            className="text-white group-hover:text-yellow-300 transition-colors duration-300"
          />
        ),
        step: "STEP 1 :",
        description: "Check for your vehicle model under",
        highlight: "COMPATIBLE LIST",
      },
      {
        icon: (
          <FontAwesomeIcon
            icon={faMapMarkerAlt}
            size="2x"
            className="text-white group-hover:text-yellow-300 transition-colors duration-300"
          />
        ),
        step: "STEP 2 :",
        description: "To check for fitment in your location, enter",
        highlight: "PINCODE",
      },
      {
        icon: (
          <FontAwesomeIcon
            icon={faShoppingCart}
            size="2x"
            className="text-white group-hover:text-yellow-300 transition-colors duration-300"
          />
        ),
        step: "STEP 3 :",
        description: "Click on",
        highlight: "BUY NOW",
      },
      {
        icon: (
          <FontAwesomeIcon
            icon={faAddressCard}
            size="2x"
            className="text-white group-hover:text-yellow-300 transition-colors duration-300"
          />
        ),
        step: "STEP 4 :",
        description: "Enter your full information &",
        highlight: "CONTACT DETAILS",
      },
      {
        icon: (
          <FontAwesomeIcon
            icon={faCreditCard}
            size="2x"
            className="text-white group-hover:text-yellow-300 transition-colors duration-300"
          />
        ),
        step: "STEP 5 :",
        description: "Leads to a gateway to",
        highlight: "MAKE PAYMENT",
      },
      {
        icon: (
          <FontAwesomeIcon
            icon={faDoorOpen}
            size="2x"
            className="text-white group-hover:text-yellow-300 transition-colors duration-300"
          />
        ),
        step: "STEP 6 :",
        description: "Product reaches your",
        highlight: "DOORSTEP",
      },
    ];

    return (
      <div className="bg-white py-12 px-4 my-[4%]" id="userjourney3">
        <div className="container mx-auto">
          <h1 className="text-center text-3xl md:text-4xl font-semibold text-tegblue mb-12">
            HOW DO I BUY MY TYRE ONLINE?
          </h1>

          <div className="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-3 gap-8 mb-10">
            {buyingSteps.map((step, index) => (
              <div
                key={index}
                className="flex flex-col items-center text-center p-6 rounded-lg transition-all duration-300 bg-transparent hover:shadow-[0_0_15px_rgba(0,0,0,0.3)]"
              >
                <div className="bg-tegblue rounded-full p-5 mb-4 w-20 h-20 flex items-center justify-center shadow-md hover:scale-105 transition-all duration-300 group">
                  {step.icon}
                </div>
                <h3 className="text-red-600 font-semibold text-lg">
                  {step.step}
                </h3>
                <p className="text-gray-500 mb-1">{step.description}</p>
                <h4 className="text-tegblue  text-2xl">{step.highlight}</h4>
              </div>
            ))}
          </div>

          {/* Buy Now Button */}
          <div className="flex justify-center mt-8">
            <a
              href="/product-category/two-wheeler/"
              target="_blank"
              className="relative overflow-hidden bg-tegblue text-white rounded-md w-full max-w-xs py-3 px-6 flex items-center justify-center group transition-all duration-300"
              rel="noreferrer"
            >
              {/* Red background that slides from bottom-right to top-left on hover */}
              <span className="absolute inset-0 bg-red-600 origin-bottom-right translate-x-full translate-y-full rotate-45 scale-0 group-hover:scale-[2.5] group-hover:translate-x-0 group-hover:translate-y-0 group-hover:rotate-0 transition-all duration-500 ease-in-out"></span>

              {/* Default state */}
              <div className="flex items-center justify-center space-x-2 relative z-10 transition-all duration-300 w-full">
                <span className="group-hover:opacity-0 transition-opacity duration-300 flex items-center">
                  <FontAwesomeIcon icon={faShoppingCart} className="mr-2" />
                  <span>Buy Now</span>
                </span>

                {/* Hover state */}
                <span className="absolute inset-0 flex items-center justify-center opacity-0 group-hover:opacity-100 transition-opacity duration-300">
                  <FontAwesomeIcon icon={faSearch} className="mr-2" />
                  <span>Search Tyres</span>
                </span>
              </div>
            </a>
          </div>
        </div>
      </div>
    );
  }

  function TyreMaintenance() {
    const maintenanceTips = [
      {
        icon: (
          <FontAwesomeIcon
            icon={faBook}
            size="2x"
            className="text-white group-hover:text-yellow-300 transition-colors duration-300"
          />
        ),
        description: "Refer vehicle manual for",
        highlight: "EXACT TYRE SIZE",
      },
      {
        icon: (
          <FontAwesomeIcon
            icon={faSpinner}
            size="2x"
            className="text-white group-hover:text-yellow-300 transition-colors duration-300"
          />
        ),
        description: "Refer manual for Optimal",
        highlight: "AIR PRESSURE",
      },
      {
        icon: (
          <FontAwesomeIcon
            icon={faHandsWash}
            size="2x"
            className="text-white group-hover:text-yellow-300 transition-colors duration-300"
          />
        ),
        description: "Wash your tyres with mild",
        highlight: "SOAP & WATER",
      },
      {
        icon: (
          <FontAwesomeIcon
            icon={faDiceD20}
            size="2x"
            className="text-white group-hover:text-yellow-300 transition-colors duration-300"
          />
        ),
        description: "Keep checking if tread level is",
        highlight: "MORE THAN 3MM",
      },
      {
        icon: (
          <FontAwesomeIcon
            icon={faEquals}
            size="2x"
            className="text-white group-hover:text-yellow-300 transition-colors duration-300"
          />
        ),
        description: "Once in 6 months check",
        highlight: "WHEEL ALIGNMENT",
      },
      {
        icon: (
          <FontAwesomeIcon
            icon={faBahai}
            size="2x"
            className="text-white group-hover:text-yellow-300 transition-colors duration-300"
          />
        ),
        description: "Ensure prompt repair & care on",
        highlight: "PUNCTURE",
      },
    ];

    return (
      <div className="bg-white py-12 px-4 my-[4%]" id="userjourney5">
        <div className="container mx-auto">
          <h1 className="text-center text-3xl md:text-4xl font-semibold text-tegblue mb-12">
            HOW DO I MAINTAIN MY TYRE?
          </h1>

          <div className="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-3 gap-8 mb-10">
            {maintenanceTips.map((tip, index) => (
              <div
                key={index}
                className="flex flex-col items-center text-center p-6 rounded-lg transition-all duration-300 bg-transparent hover:shadow-[0_0_15px_rgba(0,0,0,0.3)]"
              >
                <div className="bg-tegblue rounded-full p-5 mb-4 w-20 h-20 flex items-center justify-center shadow-md hover:scale-105 transition-all duration-300 group">
                  {tip.icon}
                </div>
                <p className="text-gray-500 mb-1">{tip.description}</p>
                <h4 className="text-tegblue text-2xl">{tip.highlight}</h4>
              </div>
            ))}
          </div>

          {/* More Info Button */}
          <div className="flex justify-center mt-8">
            <a
              href="https://tvseurogrip.com/2021/12/28/how-to-maintain-your-motorcycle-tyres/"
              target="_blank"
              className="relative overflow-hidden bg-tegblue text-white rounded-md w-full max-w-xs py-3 px-6 flex items-center justify-center group transition-all duration-300"
              rel="noreferrer"
            >
              {/* Red background that slides from bottom-right to top-left on hover */}
              <span className="absolute inset-0 bg-red-600 origin-bottom-right translate-x-full translate-y-full rotate-45 scale-0 group-hover:scale-[2.5] group-hover:translate-x-0 group-hover:translate-y-0 group-hover:rotate-0 transition-all duration-500 ease-in-out"></span>

              {/* Default state */}
              <div className="flex items-center justify-center space-x-2 relative z-10 transition-all duration-300 w-full">
                <span className="group-hover:opacity-0 transition-opacity duration-300 flex items-center">
                  <FontAwesomeIcon icon={faInfo} className="mr-2" />
                  <span>More Info</span>
                </span>

                {/* Hover state */}
                <span className="absolute inset-0 flex items-center justify-center opacity-0 group-hover:opacity-100 transition-opacity duration-300">
                  <FontAwesomeIcon icon={faBookReader} className="mr-2" />
                  <span>Tyre Guide</span>
                </span>
              </div>
            </a>
          </div>
        </div>
      </div>
    );
  }
  // Function to handle hash changes and scroll to the correct section
  const scrollToUserJourney = () => {
    // Get the hash without the # symbol
    const hash = window.location.hash.substring(1);

    if (hash && journeyRefs.current[hash]) {
      // Scroll to the element with a small delay to ensure rendering is complete
      setTimeout(() => {
        journeyRefs.current[hash]?.scrollIntoView({ behavior: "smooth" });
      }, 100);
    }
  };

  useEffect(() => {
    // Handle initial load with hash in URL
    if (window.location.hash) {
      scrollToUserJourney();
    }

    // Add event listener for hash changes
    window.addEventListener("hashchange", scrollToUserJourney);

    // Clean up event listener
    return () => {
      window.removeEventListener("hashchange", scrollToUserJourney);
    };
  }, []);
  return (
    <div className="">
      <div className="mb-5">
        <Breadcrumbs />
      </div>
      <div className="user-journey my-[4%]">
        <div className="h-[400px] flex  flex-col text-tegblue justify-center items-center">
          <h1 className="text-3xl uppercase text-center font-semibold">
            YOUR GUIDE TO SELECT THE RIGHT TYRE
          </h1>
          <h1 className="text-3xl uppercase leading-0 text-center font-semibold">
            FOR YOUR BIKE IN 5 MINUTES
          </h1>
        </div>
      </div>
      <TyreCheck />
      <TyreSelect />
      <TyreBuyOnline />
      <div
        className="w-full bg-cover bg-center mb-[4%]"
        style={{ backgroundImage: `url(${bestChoiceImage})` }}
        id="userjourney4"
      >
        <BoxContainer>
          <div className="flex flex-col items-center justify-center py-12 md:py-16 lg:py-24 px-4">
            <h1 className="my-5 text-2xl sm:text-3xl md:text-4xl text-white font-bold text-center max-w-5xl">
              HOW DO I REGISTER FOR WARRANTY?
            </h1>

            <div className="grid grid-cols-1 sm:grid-cols-2 lg:grid-cols-4 gap-4 md:gap-6 lg:gap-8 w-full mt-6">
              {registrationSteps.map((step, i) => (
                <div
                  key={i}
                  className="flex justify-center items-center w-full"
                >
                  <div className="relative w-full">
                    <Image
                      src={bestChoiceBadge || "/placeholder.svg"}
                      alt={`Step ${i + 1} badge`}
                      width={500}
                      height={300}
                      className="w-full h-auto"
                      priority={i < 2}
                    />

                    <div className="absolute top-1/2 left-1/2 transform -translate-x-1/2 -translate-y-1/2 w-[90%]">
                      <div className="text-center px-4 py-3 sm:px-5 sm:py-4 rounded-md ">
                        <span
                          className={cn(
                            "font-bold block mb-2",
                            "text-base sm:text-lg md:text-xl"
                          )}
                        >
                          {step.step}
                        </span>
                        <span className="text-sm sm:text-lg">
                          {step.content}
                        </span>
                      </div>
                    </div>
                  </div>
                </div>
              ))}
            </div>
            {/* More Info Button */}
            <div className="flex justify-center ">
              <a
                href="https://tvseurogrip.com/warranty-registration/"
                target="_blank"
                className="relative overflow-hidden bg-tegblue text-white rounded-md w-full max-w-xs py-3 px-6 flex items-center justify-center group transition-all duration-300"
                rel="noreferrer"
              >
                {/* Red background that slides from bottom-right to top-left on hover */}
                <span className="absolute inset-0 bg-red-600 origin-bottom-right translate-x-full translate-y-full rotate-45 scale-0 group-hover:scale-[2.5] group-hover:translate-x-0 group-hover:translate-y-0 group-hover:rotate-0 transition-all duration-500 ease-in-out"></span>

                {/* Default state */}
                <div className="flex items-center justify-center space-x-2 w-full relative z-10 transition-all duration-300 w-full">
                  <span className="group-hover:opacity-0 transition-opacity duration-300 flex items-center">
                    <FontAwesomeIcon icon={faUserCircle} className="mr-2" />
                    <span className="font-semibold text-sm">Register now</span>
                  </span>

                  {/* Hover state */}
                  <span className="absolute inset-0 flex items-center justify-center opacity-0 group-hover:opacity-100 transition-opacity duration-300">
                    <span>Enter Detail</span>
                  </span>
                </div>
              </a>
            </div>
          </div>
        </BoxContainer>
      </div>
      <TyreMaintenance />
    </div>
  );
}
