"use client";
import BoxContainer from "@/components/shared/box-container";
import Breadcrumbs from "@/components/shared/Breadcrumbs";
import VideoBanner from "@/components/shared/video-banner";
import VideoGallery from "@/components/shared/video-gallery";
import {
  videos1,
  videos2,
  videos3,
  videos4,
  videos5,
  videos6,
} from "@/constants/form-constants";
import {
  faChessKing,
  faExpandArrowsAlt,
  faHandshake,
  faHandSparkles,
  faHeart,
  faSmile,
  faTools,
} from "@fortawesome/free-solid-svg-icons";
import { FontAwesomeIcon } from "@fortawesome/react-fontawesome";
import Link from "next/link";
import React from "react";

function ButtonWithIcon({ icon, text, link }: any) {
  return (
    <div className="flex justify-center items-center mb-8">
      <Link
        href={link}
        className="inline-flex mx-auto items-center gap-2 px-4 py-2 bg-tegblue text-white rounded hover:bg-red-700 transition-colors"
      >
        <span className="flex items-center gap-2">
          <FontAwesomeIcon icon={icon} className="h-4 w-4" />
          <span className="text-sm font-medium">{text}</span>
        </span>
      </Link>
    </div>
  );
}

const VideoTestimonials = () => {
  return (
    <div>
      <div className="mb-5">
        <Breadcrumbs />
      </div>
      <VideoBanner />
      <BoxContainer>
        <div className="flex flex-col md:flex-row md:items-center justify-center bg-gray-200 p-3 mb-4 gap-4">
          <div className="mx-auto md:mx-0">
            <div className="bg-red-600 text-white w-12 h-12 rounded-full inline-flex items-center justify-center">
              <FontAwesomeIcon icon={faTools} className="h-6 w-6" />
            </div>
          </div>
          <div className="text-center md:text-left">
            <h3 className="text-xl uppercase text-tegblue font-semibold">
              Eurostarz speak
            </h3>
          </div>
        </div>
        <VideoGallery videos={videos1} />
        <ButtonWithIcon
          icon={faChessKing}
          text={`I'm Interested to be an Eurostarz Mechanic`}
          link={"/become-our-dealer"}
        />
        <div className="flex flex-col md:flex-row md:items-center justify-center bg-gray-200 p-3 mb-4 gap-4">
          <div className="mx-auto md:mx-0">
            <div className="bg-red-600 text-white w-12 h-12 rounded-full inline-flex items-center justify-center">
              <FontAwesomeIcon icon={faTools} className="h-6 w-6" />
            </div>
          </div>
          <div className="text-center md:text-left">
            <h3 className="text-xl text-tegblue font-semibold">
              DISTRIBUTORS SPEAK
            </h3>
          </div>
        </div>
        <VideoGallery videos={videos2} />
        <VideoGallery videos={videos3} />
        <ButtonWithIcon
          icon={faHandSparkles }
          text={`I'm Interested to be a Distributor`}
          link={"/become-our-dealer"}
        />
        <div className="flex flex-col md:flex-row md:items-center justify-center bg-gray-200 p-3 mb-4 gap-4">
          <div className="mx-auto md:mx-0">
            <div className="bg-red-600 text-white w-12 h-12 rounded-full inline-flex items-center justify-center">
              <FontAwesomeIcon icon={faExpandArrowsAlt} className="h-6 w-6" />
            </div>
          </div>
          <div className="text-center md:text-left">
            <h3 className="text-xl text-tegblue font-semibold">
              RETAILERS voice
            </h3>
          </div>
        </div>
        <VideoGallery videos={videos4} />
        <VideoGallery videos={videos5} />
        <ButtonWithIcon
          icon={faHandshake }
          text={`I'm Interested to be a Retailer`}
          link={"/become-our-dealer"}
        />
        <div className="flex flex-col md:flex-row md:items-center justify-center bg-gray-200 p-3 mb-4 gap-4">
          <div className="mx-auto md:mx-0">
            <div className="bg-red-600 text-white w-12 h-12 rounded-full inline-flex items-center justify-center">
              <FontAwesomeIcon icon={faSmile} className="h-6 w-6" />
            </div>
          </div>
          <div className="text-center md:text-left">
            <h3 className="text-xl text-tegblue font-semibold">
            {"I'm Interested to Share my Review"}
            </h3>
          </div>
        </div>
        <VideoGallery videos={videos6} />
        <ButtonWithIcon
          icon={faHeart }
          text={`I'm Interested to be an Eurostarz Mechanic`}
          link={"/become-our-dealer"}
        />
      </BoxContainer>
    </div>
  );
};

export default VideoTestimonials;
