import { NextResponse } from "next/server"

export async function GET(request: Request) {
  const { searchParams } = new URL(request.url)
  const selectedCat = searchParams.get("category") || ""
  const selectedSubCat = searchParams.get("subcategory") || ""
  const page = searchParams.get("page") || "1"

  let url = "https://tyrefinder.co.in/api/blogs?populate=*&pagination[pageSize]=10"

  if (selectedCat) {
    url += `&filters[blog_category][slug][$eq]=${selectedCat}`
  }

  if (selectedSubCat) {
    url += `&filters[blog_subcategory][slug][$eq]=${selectedSubCat}`
  }

  try {
    const response = await fetch(url)

    if (!response.ok) {
      throw new Error(`Failed to fetch blogs: ${response.status}`)
    }

    const data = await response.json()
    return NextResponse.json(data)
  } catch (error) {
    console.error("Error fetching blogs:", error)
    return NextResponse.json({ error: "Failed to fetch blogs" }, { status: 500 })
  }
}

