import { NextRequest, NextResponse } from 'next/server';
import FinancialResultsData from '@/database/investor-relations/financial-results.json';

export async function GET(request: NextRequest) {
  const { searchParams } = new URL(request.url);
  const title = searchParams.get('title');
  const year = searchParams.get('year');

  if (!title || !year) {
    return NextResponse.json(
      { error: 'Title and year are required parameters.' },
      { status: 400 }
    );
  }

  const result = FinancialResultsData?.filter((items) => {
    return items.year === year;
  });

  if (!result) {
    return NextResponse.json(
      { error: 'No data found for the specified title and year.' },
      { status: 404 }
    );
  }

  // Return the result as JSON
  return NextResponse.json({
    data: result,
  });
}
