import { NextResponse } from "next/server"

export async function POST(request: Request) {
  try {
    const requestBody = await request.json()

    // Forward the request to the external API
    const response = await fetch("https://tyrefinder.co.in/api/orders/pretransaction", {
      method: "POST",
      headers: {
        "Content-Type": "application/json",
      },
      body: JSON.stringify(requestBody),
    })

    // Check if the response is successful
    if (!response.ok) {
      const errorData = await response.json()
      return NextResponse.json({ error: errorData.error || { message: "Payment failed" } }, { status: response.status })
    }

    // Return the successful response
    const result = await response.json()
    return NextResponse.json(result)
  } catch (error) {
    console.error("API route error:", error)
    return NextResponse.json({ error: { message: "Internal server error" } }, { status: 500 })
  }
}

