// import { NextRequest, NextResponse } from 'next/server';
// import productListing from '@/database/products/products-listing.json';

// export async function GET(req: NextRequest, res: Response) {
//   const searchParams = req?.nextUrl?.searchParams;
//   const model = searchParams.get('model');

//   if (model) {
//     const filteredByModel = productListing?.entries;

//     return NextResponse.json({ data: model });
//   }

//   return NextResponse.json(productListing);
// }

// src/app/api/products/route.ts

import { notFound } from 'next/navigation';
import { NextResponse } from 'next/server';

const ITEMS_PER_PAGE = 6;

export async function GET(request: Request) {
  const { searchParams } = new URL(request.url);
  const brand = searchParams.get('brand');
  const model = searchParams.get('model');
  const wheelPosition = searchParams.get('wheelPosition');
  const frontTyreSize = searchParams.get('frontTyreSize');
  const rearTyreSize = searchParams.get('rearTyreSize');
  const pattern = searchParams.get('pattern');
  const segment = searchParams.get('segment');
  const page = parseInt(searchParams.get('page') || '1', 10);
  const minPrice = searchParams.get('minPrice');
  const maxPrice = searchParams.get('maxPrice');

  let url =
    'https://tyrefinder.co.in/api/products?populate=*&filters[product_category][slug][$eq]=two-wheeler';

  if (brand) {
    url += `&filters[vehicle_brands][slug][$eq]=${brand}`;
  }
  if (model) {
    url += `&filters[vehicle_models][slug][$eq]=${model}`;
  }
  if (wheelPosition) {
    url += `&filters[WheelPosition][$eq]=${encodeURIComponent(wheelPosition)}`;
  }
  if (frontTyreSize) {
    url += `&filters[front_tyresize][slug][$eq]=${frontTyreSize}`;
  }
  if (rearTyreSize) {
    url += `&filters[rear_tyresize][slug][$eq]=${rearTyreSize}`;
  }
  if (pattern) {
    url += `&filters[product_pattern][slug][$eq]=${pattern}`;
  }
  if (segment) {
    url += `&filters[product_segmentation][slug][$eq]=${segment}`;
  }
  if (page) {
    url += `&pagination[page]=${page}`;
  }
  if (ITEMS_PER_PAGE) {
    url += `&pagination[pageSize]=${ITEMS_PER_PAGE}`;
  }
  if (minPrice && maxPrice) {
    url += `&filters[price][$gte]=${minPrice}&filters[price][$lte]=${maxPrice}`;
  }

  // console.log(url);

  // Add pagination parameters
  // url += `&pagination[page]=${page}&pagination[pageSize]=${ITEMS_PER_PAGE}`;

  const res = await fetch(url);

  if (!res.ok) {
    return NextResponse.json(
      { error: 'Failed to fetch products' },
      { status: 500 }
    );
  }

  const data = await res.json();
  return NextResponse.json(data);
}
