'use client';

import type React from 'react';
import { useRef, useState } from 'react';
import Image from 'next/image';
import Slider from 'react-slick';
import { sliderImages } from '@/constants/heroslider';
import { ChevronLeft, ChevronRight } from 'lucide-react';

// You'll need to add these CSS files to your project
import '@/styles/slick.css';
import '@/styles/slick-theme.css';

interface ArrowProps {
  onClick?: () => void;
}

const NextArrow = ({ onClick }: ArrowProps) => (
  <button
    onClick={onClick}
    className='absolute right-4 top-1/2 -translate-y-1/2 z-10 p-2 bg-white bg-opacity-50 rounded-full hover:bg-opacity-75 transition-all duration-200'
    aria-label='Next slide'
  >
    <ChevronRight className='w-6 h-6 text-gray-800' />
  </button>
);

const PrevArrow = ({ onClick }: ArrowProps) => (
  <button
    onClick={onClick}
    className='absolute left-4 top-1/2 -translate-y-1/2 z-10 p-2 bg-white bg-opacity-50 rounded-full hover:bg-opacity-75 transition-all duration-200'
    aria-label='Previous slide'
  >
    <ChevronLeft className='w-6 h-6 text-gray-800' />
  </button>
);

export default function HeroSlider() {
  const sliderRef = useRef<Slider>(null);
  const [currentSlide, setCurrentSlide] = useState(0);

  const goToNextSlide = () => {
    if (sliderRef.current) {
      sliderRef.current.slickNext();
    }
  };

  const goToPrevSlide = () => {
    if (sliderRef.current) {
      sliderRef.current.slickPrev();
    }
  };

  const settings = {
    dots: true,
    infinite: true,
    speed: 500,
    slidesToShow: 1,
    slidesToScroll: 1,
    autoplay: true,
    autoplaySpeed: 5000,
    nextArrow: <NextArrow onClick={goToNextSlide} />,
    prevArrow: <PrevArrow onClick={goToPrevSlide} />,
    beforeChange: (oldIndex: number, newIndex: number) => {
      setCurrentSlide(newIndex);
    },
    appendDots: (dots: React.ReactNode) => (
      <div>
        <ul className='absolute bottom-4 left-1/2 transform -translate-x-1/2 flex space-x-2'>
          {dots}
        </ul>
      </div>
    ),
    customPaging: (i: number) => (
      <button
        className={`w-3 h-3 rounded-full transition-all duration-200 focus:outline-none focus:ring-2 focus:ring-white focus:ring-opacity-50 ${
          i === currentSlide
            ? 'bg-white'
            : 'bg-white bg-opacity-50 hover:bg-opacity-75'
        }`}
        onClick={() => {
          if (sliderRef.current) {
            sliderRef.current.slickGoTo(i);
          }
        }}
        aria-label={`Go to slide ${i + 1}`}
      />
    ),
  };

  return (
    <div className='relative'>
      <Slider ref={sliderRef} {...settings}>
        {sliderImages.map((slide, index) => (
          <div
            key={index}
            className='relative w-full h-[300px] sm:h-[400px] md:h-[500px]'
          >
            <Image
              src={slide.mobile || '/placeholder.svg'}
              alt={slide.alt}
              fill
              className='object-cover md:hidden'
              sizes='100vw'
              priority={index === 0}
            />
            <Image
              src={slide.desktop || '/placeholder.svg'}
              alt={slide.alt}
              fill
              className='hidden md:block object-cover'
              sizes='100vw'
              priority={index === 0}
            />
          </div>
        ))}
      </Slider>
    </div>
  );
}
