'use client';

import { useState } from 'react';
import Image from 'next/image';
import Link from 'next/link';
import { ChevronLeft, ChevronRight } from 'lucide-react';
import { faQuoteLeft, faQuoteRight } from '@fortawesome/free-solid-svg-icons';
import { FontAwesomeIcon } from '@fortawesome/react-fontawesome';

interface Quote {
  id: number;
  logo: string;
  companyName: string;
  text: string;
  date: string;
  link: string;
}

const quotes: Quote[] = [
  {
    id: 1,
    logo: '/assets/images/expert-reviews/TOI-logo.webp',
    companyName: 'Times of India',
    text: 'TVS Eurogrip has shown remarkable innovation in tyre technology, setting new standards for the industry.',
    date: 'May 15, 2023',
    link: 'https://timesofindia.indiatimes.com/auto/tyres/tvs-eurogrip-innovation',
  },
  {
    id: 2,
    logo: '/assets/images/expert-reviews/fastbikes.webp',
    companyName: 'Fast Bikes',
    text: 'The performance of TVS Eurogrip tyres in our high-speed tests was nothing short of impressive.',
    date: 'June 3, 2023',
    link: 'https://fastbikes.com/reviews/tvs-eurogrip-performance-test',
  },
  {
    id: 3,
    logo: '/assets/images/expert-reviews/bikewale.webp',
    companyName: 'BikeWale',
    text: 'TVS Eurogrip offers an excellent balance of durability and grip, making it a top choice for daily riders.',
    date: 'July 12, 2023',
    link: 'https://www.bikewale.com/news/tvs-eurogrip-tyre-review',
  },
  {
    id: 4,
    logo: '/assets/images/expert-reviews/autocar.webp',
    companyName: 'Autocar',
    text: 'In our comprehensive tyre comparison, TVS Eurogrip stood out for its exceptional wet weather performance.',
    date: 'August 20, 2023',
    link: 'https://www.autocarindia.com/tyre-tests/tvs-eurogrip-wet-weather-champion',
  },
  {
    id: 5,
    logo: '/assets/images/expert-reviews/carandbike.webp',
    companyName: 'Car and Bike',
    text: "TVS Eurogrip's latest range of tyres showcases the perfect blend of technology and rider-centric design.",
    date: 'September 5, 2023',
    link: 'https://www.carandbike.com/reviews/tvs-eurogrip-technology-meets-design',
  },
  {
    id: 6,
    logo: '/assets/images/expert-reviews/financial-express.webp',
    companyName: 'Financial Express',
    text: "TVS Eurogrip's market share growth is a testament to their commitment to quality and innovation in the tyre industry.",
    date: 'October 10, 2023',
    link: 'https://www.financialexpress.com/auto/tvs-eurogrip-market-growth',
  },
];

export default function VerticalTabQuotes() {
  const [activeQuoteIndex, setActiveQuoteIndex] = useState(0);

  const activeQuote = quotes[activeQuoteIndex];

  const goToNextQuote = () => {
    setActiveQuoteIndex((prevIndex) => (prevIndex + 1) % quotes.length);
  };

  const goToPrevQuote = () => {
    setActiveQuoteIndex(
      (prevIndex) => (prevIndex - 1 + quotes.length) % quotes.length
    );
  };

  return (
    <div className=''>
      {/* <div className='container mx-auto px-4 py-8'> */}
      <div className='flex flex-col sm:flex-row '>
        {/* Vertical Tabs (hidden on mobile) */}
        <div className='hidden sm:flex sm:w-[200px] flex-col  bg-[#295ca9] '>
          {quotes.map((quote, index) => (
            <button
              key={quote.id}
              onClick={() => setActiveQuoteIndex(index)}
              className={`px-6 py-3 transition-all duration-300 ${
                index === activeQuoteIndex
                  ? 'bg-[#224e8f] shadow-md '
                  : 'bg-[#295ca9] bg-opacity-80 hover:bg-opacity-100'
              }`}
            >
              <Image
                src={quote.logo || '/placeholder.svg'}
                alt={quote.companyName}
                width={180}
                height={90}
                className='w-full brightness-0 invert'
              />
            </button>
          ))}
        </div>

        {/* Quote Display */}
        <div className='sm:w-3/4 bg-white p-6 rounded-lg shadow-md'>
          {/* Mobile Logo Display */}
          <div className='sm:hidden mb-4 flex justify-center'>
            <div className='bg-[#295ca9] p-4 rounded-lg'>
              <Image
                src={activeQuote.logo || '/placeholder.svg'}
                alt={activeQuote.companyName}
                width={150}
                height={75}
                className='object-contain h-16 brightness-0 invert'
              />
            </div>
          </div>

          <div className='text-left'>
            <FontAwesomeIcon
              icon={faQuoteLeft}
              size={'lg'}
              className='mr-1 '
              color={'#cccccc'}
            />

            <p className='text-xl italic mb-4'>{activeQuote.text}</p>
            <FontAwesomeIcon
              icon={faQuoteRight}
              size={'lg'}
              className='mr-1 '
              color={'#cccccc'}
            />
            <div className='flex flex-col items-start'>
              <div className='text-left'>
                <p className='font-semibold'>{activeQuote.companyName}</p>
                <p className='text-sm text-gray-600'>{activeQuote.date}</p>
              </div>
              <Link
                href={activeQuote.link}
                target='_blank'
                rel='noopener noreferrer'
                className='bg-[#295ca9] text-white px-4 py-2 rounded hover:bg-[#1e4786] transition-colors'
              >
                Read More
              </Link>
            </div>
          </div>

          {/* Mobile Navigation Arrows */}
          <div className='flex justify-between mt-6 sm:hidden'>
            <button
              onClick={goToPrevQuote}
              className='p-2 bg-[#295ca9] text-white rounded-full'
              aria-label='Previous quote'
            >
              <ChevronLeft size={24} />
            </button>
            <button
              onClick={goToNextQuote}
              className='p-2 bg-[#295ca9] text-white rounded-full'
              aria-label='Next quote'
            >
              <ChevronRight size={24} />
            </button>
          </div>
        </div>
      </div>
    </div>
  );
}
