import Image from 'next/image';
import Link from 'next/link';
import RichTextRenderer from '../rich-text-renderer';
import { truncateString } from '@/lib/utils';

interface BlogCardProps {
  thumbnail: string;
  title: string;
  description: string;
  readMoreLink: string;
  date: string;
  commentCount: number;
}

export default function BlogCard({
  thumbnail,
  title,
  description,
  readMoreLink,
  date,
  commentCount,
}: BlogCardProps) {
  return (
    <div className='bg-white rounded-lg shadow-md overflow-hidden'>
      {/* Thumbnail */}
      <div className='relative min-h-36 h-36 w-full'>
        <Image
          src={thumbnail || '/placeholder.svg'}
          alt={title}
          fill
          className='object-cover'
          sizes='(max-width: 768px) 100vw, (max-width: 1200px) 50vw, 33vw'
        />
      </div>

      <div className='flex flex-col'>
        <div className='p-4'>
          <h2 className='text-[12px] text-[#295CA9] font-semibold mb-2'>
            {title}
          </h2>
          <p className='text-gray-600 text-[12px] font-normal mb-4 min-h-24'>
            <RichTextRenderer content={truncateString(description, 150)} />
          </p>
          <Link
            href={readMoreLink}
            className='inline-block text-[#C50000] text-[12px] font-semibold uppercase'
          >
            Read More
          </Link>
        </div>

        <div className='bg-gray-100 px-4 py-3 flex gap-1 items-center text-[12px] text-gray-600'>
          <span>{date}</span>•
          <span>
            {commentCount === 0
              ? 'No comments'
              : commentCount === 1
              ? '1 comment'
              : `${commentCount} comments`}
          </span>
        </div>
      </div>
    </div>
  );
}
