'use client';

import { type ReactNode, useEffect } from 'react';
import { useBlogStore } from '@/store/useBlogStore';

interface FilterProviderProps {
  children: ReactNode;
  initialCategory?: string;
}

export function FilterProvider({
  children,
  initialCategory,
}: FilterProviderProps) {
  const {
    categories,
    subcategories,
    setSelectedCategory,
    setSelectedSubcategory,
    fetchCategories,
    fetchSubcategories,
  } = useBlogStore();

  useEffect(() => {
    // Fetch categories and subcategories
    fetchCategories();
    fetchSubcategories();
  }, [fetchCategories, fetchSubcategories]);

  useEffect(() => {
    if (!initialCategory) return;

    // Check if the category matches any category
    const matchingCategory = categories.find(
      (category) => category.attributes.slug === initialCategory
    );

    if (matchingCategory) {
      setSelectedCategory(initialCategory);
      return;
    }

    // Check if the category matches any subcategory
    const matchingSubcategory = subcategories.find(
      (subcategory) => subcategory.attributes.slug === initialCategory
    );

    if (matchingSubcategory) {
      setSelectedSubcategory(initialCategory);
      return;
    }
  }, [
    initialCategory,
    categories,
    subcategories,
    setSelectedCategory,
    setSelectedSubcategory,
  ]);

  return <>{children}</>;
}
