'use client';

import { useEffect } from 'react';
import { Button } from '@/components/ui/button';
import { useBlogStore } from '@/store/useBlogStore';
import { Skeleton } from '@/components/ui/skeleton';

export default function Sidebar() {
  const {
    categories,
    subcategories,
    selectedCategory,
    selectedSubcategory,
    setSelectedCategory,
    setSelectedSubcategory,
    fetchCategories,
    fetchSubcategories,
  } = useBlogStore();

  useEffect(() => {
    fetchCategories();
    fetchSubcategories();
  }, [fetchCategories, fetchSubcategories]);

  const handleCategoryClick = (slug: string) => {
    if (selectedCategory === slug) {
      setSelectedCategory(null);
    } else {
      setSelectedCategory(slug);
    }
  };

  const handleSubcategoryClick = (slug: string) => {
    if (selectedSubcategory === slug) {
      setSelectedSubcategory(null);
    } else {
      setSelectedSubcategory(slug);
    }
  };

  const handleClearFilters = () => {
    setSelectedCategory(null);
    setSelectedSubcategory(null);
  };

  if (categories.length === 0 || subcategories.length === 0) {
    return (
      <div className='space-y-4'>
        <h2 className='text-xl font-semibold'>Filters</h2>
        <div className='space-y-2'>
          <Skeleton className='h-8 w-full' />
          <Skeleton className='h-8 w-full' />
          <Skeleton className='h-8 w-full' />
        </div>
      </div>
    );
  }

  return (
    <div className='space-y-6 sticky top-4'>
      <div className='space-y-4'>
        <div className='flex justify-between items-center'>
          <h2 className='text-xl font-semibold'>Filters</h2>
          {(selectedCategory || selectedSubcategory) && (
            <Button variant='ghost' size='sm' onClick={handleClearFilters}>
              Clear
            </Button>
          )}
        </div>

        {/* Categories Section */}
        <div className='space-y-2'>
          <h3 className='font-medium'>Categories</h3>
          <div className='flex flex-col gap-2'>
            {categories.map((category) => (
              <Button
                key={category.id}
                variant={
                  selectedCategory === category.attributes.slug
                    ? 'default'
                    : 'outline'
                }
                size='sm'
                onClick={() => handleCategoryClick(category.attributes.slug)}
                className={
                  selectedCategory === category.attributes.slug
                    ? 'text-primary-foreground text-left'
                    : 'text-foreground hover:text-foreground text-left'
                }
              >
                {category.attributes.Categoryname}
              </Button>
            ))}
          </div>
        </div>

        {/* Subcategories Section - Always visible */}
        <div className='space-y-2 pt-2 border-t'>
          <h3 className='font-medium'>Subcategories</h3>
          <div className='flex flex-col gap-2'>
            {subcategories.map((subcategory) => (
              <Button
                key={subcategory.id}
                variant={
                  selectedSubcategory === subcategory.attributes.slug
                    ? 'default'
                    : 'outline'
                }
                size='sm'
                onClick={() =>
                  handleSubcategoryClick(subcategory.attributes.slug)
                }
                className={
                  selectedSubcategory === subcategory.attributes.slug
                    ? 'text-primary-foreground'
                    : 'text-foreground hover:text-foreground'
                }
              >
                {subcategory.attributes.name}
              </Button>
            ))}
          </div>
        </div>
      </div>
    </div>
  );
}
