"use client";
import Image from "next/image";
import { useEffect, useState } from "react";
import Slider from "react-slick";

export default function GloballyCertifiedSection() {
  const [mounted, setMounted] = useState(false);

  useEffect(() => {
    setMounted(true);

    // Add slick CSS dynamically
    const linkElems = [
      document.createElement("link"),
      document.createElement("link"),
    ];

    linkElems[0].rel = "stylesheet";
    linkElems[0].type = "text/css";
    linkElems[0].href =
      "https://cdnjs.cloudflare.com/ajax/libs/slick-carousel/1.6.0/slick.min.css";

    linkElems[1].rel = "stylesheet";
    linkElems[1].type = "text/css";
    linkElems[1].href =
      "https://cdnjs.cloudflare.com/ajax/libs/slick-carousel/1.6.0/slick-theme.min.css";

    linkElems.forEach((link) => document.head.appendChild(link));

    return () => {
      linkElems.forEach((link) => {
        if (document.head.contains(link)) {
          document.head.removeChild(link);
        }
      });
    };
  }, []);

  const certifications = [
    {
      src: "https://tvseurogrip.com/wp-content/uploads/2022/01/GLOBAL-certifications-3.jpg",
      webp: "https://tvseurogrip.com/wp-content/uploads/2022/01/GLOBAL-certifications-3.jpg.webp",
      title: "Brazilian Standard",
      alt: "Brazilian Standard",
    },
    {
      src: "https://tvseurogrip.com/wp-content/uploads/2022/01/GLOBAL-certifications-5.jpg",
      webp: "https://tvseurogrip.com/wp-content/uploads/2022/01/GLOBAL-certifications-5.jpg.webp",
      title: "FMVSS (DOT)",
      alt: "FMVSS (DOT)",
    },
    {
      src: "https://tvseurogrip.com/wp-content/uploads/2022/01/GLOBAL-certifications-4.jpg",
      webp: "https://tvseurogrip.com/wp-content/uploads/2022/01/GLOBAL-certifications-4.jpg.webp",
      title: "Gulf Standard Organization",
      alt: "Gulf Standard Organization",
    },
    {
      src: "https://tvseurogrip.com/wp-content/uploads/2022/01/GLOBAL-certifications-2.jpg",
      webp: "https://tvseurogrip.com/wp-content/uploads/2022/01/GLOBAL-certifications-2.jpg.webp",
      title: "Indonesia Standards",
      alt: "Indonesia Standards",
    },
    {
      src: "https://tvseurogrip.com/wp-content/uploads/2022/01/GLOBAL-certifications-1.jpg",
      webp: "https://tvseurogrip.com/wp-content/uploads/2022/01/GLOBAL-certifications-1.jpg.webp",
      title: "South Africa Bureau of Standards",
      alt: "South Africa Bureau of Standards",
    },
    {
      src: "https://tvseurogrip.com/wp-content/uploads/2022/01/GLOBAL-certifications-6.jpg",
      webp: "https://tvseurogrip.com/wp-content/uploads/2022/01/GLOBAL-certifications-6.jpg.webp",
      title: "Bureau of Indian Standards",
      alt: "Bureau of Indian Standards",
    },
    {
      src: "https://tvseurogrip.com/wp-content/uploads/2022/01/GLOBAL-certifications-7.jpg",
      webp: "https://tvseurogrip.com/wp-content/uploads/2022/01/GLOBAL-certifications-7.jpg.webp",
      title:
        "Registration, Evaluation, Authorization & Restriction of Chemical",
      alt: "Registration, Evaluation, Authorization & Restriction of Chemical",
    },
    {
      src: "https://tvseurogrip.com/wp-content/uploads/2022/01/GLOBAL-certifications-8.jpg",
      webp: "https://tvseurogrip.com/wp-content/uploads/2022/01/GLOBAL-certifications-8.jpg.webp",
      title: "ECE",
      alt: "ECE",
    },
  ];

  const sliderSettings = {
    dots: true,
    infinite: true,
    speed: 500,
    slidesToShow: 4,
    slidesToScroll: 1,
    autoplay: true,
    autoplaySpeed: 3000,
    responsive: [
      {
        breakpoint: 1024,
        settings: {
          slidesToShow: 3,
          slidesToScroll: 1,
        },
      },
      {
        breakpoint: 768,
        settings: {
          slidesToShow: 2,
          slidesToScroll: 1,
        },
      },
      {
        breakpoint: 480,
        settings: {
          slidesToShow: 1,
          slidesToScroll: 1,
        },
      },
    ],
  };

  return (
    <div className="px-4 w-full">
      <div className="flex flex-col md:flex-row items-start">
        {/* Certifications in a slider */}
        <div className="md:w-3/4">
          {mounted ? (
            <Slider {...sliderSettings}>
              {certifications.map((cert, index) => (
                <div key={index} className="px-2">
                  <div className="flex flex-col items-center text-center">
                    <div className="h-20 flex items-center justify-center mb-4 relative">
                      <Image
                        src={cert.src || "/placeholder.svg"}
                        alt={cert.alt}
                        width={120}
                        height={80}
                        sizes="(max-width: 480px) 80vw, (max-width: 768px) 40vw, (max-width: 1024px) 25vw, 120px"
                        className="max-h-full w-auto object-contain"
                      />
                    </div>
                    <p className="text-xs sm:text-sm text-gray-700 font-medium max-w-[120px] mx-auto">
                      {cert.title}
                    </p>
                  </div>
                </div>
              ))}
            </Slider>
          ) : (
            <div className="flex flex-wrap justify-between">
              {certifications.map((cert, index) => (
                <div key={index} className="w-1/2 md:w-1/3 px-2 mb-4">
                  <div className="flex flex-col items-center text-center">
                    <div className="h-20 flex items-center justify-center mb-4 relative">
                      <Image
                        src={cert.src || "/placeholder.svg"}
                        alt={cert.alt}
                        width={120}
                        height={80}
                        sizes="(max-width: 768px) 40vw, (max-width: 1024px) 30vw, 120px"
                        className="max-h-full w-auto object-contain"
                      />
                    </div>
                    <p className="text-xs sm:text-sm text-gray-700 font-medium max-w-[120px] mx-auto">
                      {cert.title}
                    </p>
                  </div>
                </div>
              ))}
            </div>
          )}
        </div>
      </div>
    </div>
  );
}
