import React from 'react';
import { SocialMenu } from '@/components/shared/navigation/SocialMenu';
import BoxContainer from './box-container';
import {
  faEye,
  faExchangeAlt,
  faShieldAlt,
  faUserTie,
  faEdit,
} from '@fortawesome/free-solid-svg-icons';
import { icon, IconDefinition } from '@fortawesome/fontawesome-svg-core';
import { FontAwesomeIcon } from '@fortawesome/react-fontawesome';

// Define the type for menu items
interface MenuItem {
  id: number;
  text: string;
  link: string;
}
interface MenuItem2 {
  id: number;
  text: string;
  link: string;
  icon: IconDefinition;
}

// Define the type for the FooterWidget component props
interface FooterWidgetProps {
  children: React.ReactNode;
}

// Define the type for the FooterWidgetTitle component props
interface FooterWidgetTitleProps {
  children: React.ReactNode;
}

// Define the type for the FooterWidgetContent component props
interface FooterWidgetContentProps {
  children: React.ReactNode;
}

// FooterWidget component
const FooterWidget: React.FC<FooterWidgetProps> = ({ children }) => {
  return (
    <div className='footer-widget w-[33.3%] flex flex-col justify-start items-center'>
      {children}
    </div>
  );
};

// FooterWidgetTitle component
const FooterWidgetTitle: React.FC<FooterWidgetTitleProps> = ({ children }) => {
  return <h3 className='footer-title'>{children}</h3>;
};

// FooterWidgetContent component
const FooterWidgetContent: React.FC<FooterWidgetContentProps> = ({
  children,
}) => {
  return <div className='footer-content'>{children}</div>;
};

// GlobalFooter component
const GlobalFooter: React.FC = () => {
  const menu: MenuItem[] = [
    { id: 1, text: 'Two Wheeler Tyres', link: '/two-wheeler-tyre' },
    { id: 2, text: 'Motosport', link: '/motosport-biking' },
    // { id: 3, text: 'Tyre Patterns', link: '/pattern-details' },
    { id: 4, text: 'Tyre Guide', link: '/blog/tyre-guide' },
    // { id: 5, text: 'Specialist Suggest', link: '/product-segmentation' },
    { id: 6, text: 'Product Video', link: '/video-testimonials' },
    { id: 7, text: 'Warranty Registration', link: '/warranty-registration' },
    { id: 8, text: 'Warranty Policy', link: '/warranty-policy' },
  ];

  const menu2: MenuItem2[] = [
    {
      id: 1,
      text: 'Return Policy',
      link: '/return-policy',
      icon: faExchangeAlt,
    },
    {
      id: 2,
      text: 'Privacy Policy',
      link: '/privacy-policy',
      icon: faShieldAlt,
    },
    {
      id: 3,
      text: 'Code of Conduct',
      link: '/code-of-conduct-2/',
      icon: faUserTie,
    },
    {
      id: 4,
      text: 'T&C of Sale / Service',
      link: '/terms-and-conditions-of-sales-service',
      icon: faEdit,
    },
  ];

  const socialmenu: MenuItem[] = [
    {
      id: 1,
      text: 'Youtube',
      link: 'https://www.youtube.com/channel/UC_NPSed8hb1on8JLmt9PAyw',
    },
    {
      id: 2,
      text: 'Facebook',
      link: 'https://www.facebook.com/TVSEurogrip',
    },
    {
      id: 3,
      text: 'Instagram',
      link: 'https://instagram.com/tvseurogrip?igshid=ZDc4ODBmNjlmNQ==',
    },
    {
      id: 4,
      text: 'LinkedIn',
      link: 'https://in.linkedin.com/company/tvs-eurogrip',
    },
    {
      id: 5,
      text: 'Twitter',
      link: 'https://twitter.com/tvseurogrip',
    },
  ];

  return (
    <section
      className='hidden lg:block'
      style={{
        backgroundImage: "url('/assets/images/footer/SHA_0684.jpg')",
        position: 'relative',
        color: '#fff',
        padding: '50px 0 80px 0',
      }}
    >
      <div
        style={{
          position: 'absolute',
          top: 0,
          left: 0,
          width: '100%',
          height: '100%',
          backgroundColor: 'rgba(0, 0, 0, 0.5)', // Semi-transparent black
          backdropFilter: 'blur(4px)', // Adds a blur effect
          WebkitBackdropFilter: 'blur(4px)', // For Safari support
          zIndex: 0,
        }}
      ></div>
      <BoxContainer>
        <div className='footer-desktop-only flex relative gap-4 w-full'>
          <FooterWidget>
            <FooterWidgetTitle>Manufacturing Units</FooterWidgetTitle>
            <FooterWidgetContent>
              <address>
                Madurai: TVS Srichakra Limited, Vellaripati,
                <br /> Melur Taluk, Madurai - 625 122
              </address>
              <address>
                Uttarakhand: TVS Srichakra Limited, Integrated Industrial
                Estate,
                <br />
                Sidcul, Pant Nagar, Rudrapur Tehsil,
                <br /> Kicha Dist., Uttarakhand - 263153
              </address>
            </FooterWidgetContent>
          </FooterWidget>
          <FooterWidget>
            <FooterWidgetTitle>Corporate Offices</FooterWidgetTitle>
            <FooterWidgetContent>
              <address>
                Chennai: TVS Srichakra Limited,
                <br />
                10, Maharani Chinnamma Road, Venus Colony,
                <br /> Teynampet, Chennai-600018.
              </address>
              <address>
                Marketing Office Chennai:
                <br /> TVS Srichakra Limited, Sudarsan Building,
                <br />
                5th Floor, 14, Whites Road
                <br /> Chennai-600 014.
                <br />
                Toll Free: 1800 123 004 400
                <br />
                email: reachus@eurogriptyres.com
              </address>
            </FooterWidgetContent>
          </FooterWidget>
          <FooterWidget>
            <FooterWidgetTitle>Two Wheeler Tyres</FooterWidgetTitle>
            <FooterWidgetContent>
              <ul>
                {menu?.map((menuItem) => {
                  return (
                    <li key={menuItem?.id}>
                      <a href={menuItem?.link}>{menuItem?.text}</a>
                    </li>
                  );
                })}
              </ul>
            </FooterWidgetContent>
          </FooterWidget>
          <FooterWidget>
            <FooterWidgetTitle>FOLLOW US ON</FooterWidgetTitle>
            <FooterWidgetContent>
              <div className='mb-4'>
                <SocialMenu />
              </div>

              <ul className='list-with-icon'>
                {menu2?.map((menuItem) => {
                  return (
                    <li
                      key={menuItem?.id}
                      className='flex gap-2 justify-start text-left'
                    >
                      <FontAwesomeIcon
                        icon={menuItem.icon}
                        className=' text-[#333333]'
                      />
                      <a href={menuItem?.link}>{menuItem?.text}</a>
                    </li>
                  );
                })}
              </ul>
              <div className='copyright-notice'>
                <small>Copyright © 2025 Eurogrip. All rights Reserved.</small>
              </div>
            </FooterWidgetContent>
          </FooterWidget>
        </div>
      </BoxContainer>
    </section>
  );
};

export default GlobalFooter;
