import BoxContainer from '@/components/shared/box-container';
import { tertiary } from '@/constants/colors';
import Link from 'next/link';
import Icon from '../../icons/Icon';
import {
  irFinance,
  irShareHolders,
  irResources,
} from '@/constants/navigation-menu';

const InvestorRelationsMegaMenu = ({ title }: { title: string }) => {
  return (
    <BoxContainer>
      <div className='flex flex-col my-[60px] text-center'>
        <h3 className='mb-6 text-white'>
          DISCLOSURE UNDER REGULATION 46 OF SEBI (LODR) REGULATIONS
        </h3>
        <div className='w-full flex flex-row text-left gap-x-6 mb-[10px]'>
          <div className='w-[33.3%]'>
            <h4 className='text-white mb-6'>FINANCIALS & FILINGS</h4>
            <ul>
              {irFinance?.map((menuItem: any, index: number) => {
                return (
                  <li key={menuItem?.id} className={`py-2 border-b`}>
                    <Link href={menuItem?.route ?? ''} className='flex'>
                      <span className='w-[20px] h-[20px] block text-[12px]'>
                        <Icon icon={menuItem?.icon} color={tertiary?.default} />
                      </span>
                      <p className='text-[13px] text-white font-sans hover:text-primary-yellow py-3 lg:py-0 lg:px-[15px] flex gap-y-4 items-center text-left'>
                        {menuItem?.text}
                      </p>
                    </Link>
                  </li>
                );
              })}
            </ul>
          </div>
          <div className='w-[33.3%]'>
            <h4 className='text-white mb-6'>SHAREHOLDERS INFORMATION</h4>
            <ul>
              {irShareHolders?.map((menuItem: any, index: number) => {
                return (
                  <li key={menuItem?.id} className={`py-2 border-b`}>
                    <Link href={menuItem?.route ?? ''} className='flex'>
                      <span className='w-[20px] h-[20px] block text-[12px]'>
                        <Icon icon={menuItem?.icon} color={tertiary?.default} />
                      </span>
                      <p className='text-[13px] text-white font-sans hover:text-primary-yellow py-3 lg:py-0 lg:px-[15px] flex gap-y-4 items-center text-left'>
                        {menuItem?.text}
                      </p>
                    </Link>
                  </li>
                );
              })}
            </ul>
          </div>
          <div className='w-[33.3%]'>
            <h4 className='text-white mb-6'>INVESTOR RESOURCE</h4>
            <ul>
              {irResources?.map((menuItem: any, index: number) => {
                return (
                  <li key={menuItem?.id} className={`py-2 border-b`}>
                    <Link href={menuItem?.route ?? ''} className='flex'>
                      <span className='w-[20px] h-[20px] block text-[12px]'>
                        <Icon icon={menuItem?.icon} color={tertiary?.default} />
                      </span>
                      <p className='text-[13px] text-white font-sans hover:text-primary-yellow py-3 lg:py-0 lg:px-[15px] flex gap-y-4 items-center text-left'>
                        {menuItem?.text}
                      </p>
                    </Link>
                  </li>
                );
              })}
            </ul>
          </div>
        </div>
      </div>
    </BoxContainer>
  );
};

export default InvestorRelationsMegaMenu;
