'use client';
import type React from 'react';
import { useState } from 'react';

interface QuantityProps {
  initialValue?: number;
  min?: number;
  max?: number;
  onChange?: (value: number) => void;
}

const Quantity = ({
  initialValue = 1,
  min = 1,
  max = 99,
  onChange,
}: QuantityProps) => {
  const [quantity, setQuantity] = useState(initialValue);

  const handleChange = (e: React.ChangeEvent<HTMLInputElement>) => {
    const newValue = Number.parseInt(e.target.value);
    if (isNaN(newValue) || newValue < min) {
      setQuantity(min);
      onChange?.(min);
    } else if (max && newValue > max) {
      setQuantity(max);
      onChange?.(max);
    } else {
      setQuantity(newValue);
      onChange?.(newValue);
    }
  };

  const increment = () => {
    if (!max || quantity < max) {
      const newValue = quantity + 1;
      setQuantity(newValue);
      onChange?.(newValue);
    }
  };

  const decrement = () => {
    if (quantity > min) {
      const newValue = quantity - 1;
      setQuantity(newValue);
      onChange?.(newValue);
    }
  };

  return (
    <div className='flex items-center border border-gray-300'>
      <button
        type='button'
        onClick={decrement}
        className='px-2 py-1 bg-gray-100 hover:bg-gray-200'
        aria-label='Decrease quantity'
      >
        -
      </button>
      <input
        type='number'
        className='input-text qty text w-full text-center border-x border-gray-300'
        name='quantity'
        value={quantity}
        aria-label='Product quantity'
        min={min}
        max={max}
        step='1'
        onChange={handleChange}
      />
      <button
        type='button'
        onClick={increment}
        className='px-2 py-1 bg-gray-100 hover:bg-gray-200'
        aria-label='Increase quantity'
      >
        +
      </button>
    </div>
  );
};

export default Quantity;
