'use client';
import { frontTyreSizeList, rearTyreSizeList } from '@/constants/tyresize';
import { useState } from 'react';
import { SelectFilter } from '../hierarchical-filter';
import { useProductStore } from '@/store/useProductStore';
import { useRouter } from 'next/navigation';

const FilterByTyrePos = () => {
  const router = useRouter();

  const {
    frontTyreSize,
    rearTyreSize,
    setFrontTyreSize,
    setRearTyreSize,
    select,
    setSelect,
  } = useProductStore();
  // const [select, setSelect] = useState('');

  // Check if either tyre size is selected (not at default value)
  const isTyreSizeSelected = frontTyreSize !== '' || rearTyreSize !== '';

  // Handle button click to redirect to product category page
  const handleFindTyres = () => {
    router.push('/product-category/two-wheeler');
  };

  return (
    <div className='flex flex-col gap-4'>
      <div>
        <select
          id='cond-display-pos'
          value={select}
          onChange={(e) => setSelect(e.target.value)}
          className='w-full border border-gray-300 rounded-md p-2 text-gray-700 bg-white focus:outline-none focus:border-[#E31837] focus:ring-1 focus:ring-[#E31837] transition-colors'
        >
          <option value=''>Choose Front or Rear</option>
          <option value='front'>Front</option>
          <option value='rear'>Rear</option>
        </select>
      </div>
      {select === 'front' && (
        <div>
          <select
            id='front-tyre-size'
            value={frontTyreSize}
            onChange={(e) => setFrontTyreSize(e.target.value)}
            className='w-full border border-gray-300 rounded-md p-2 text-gray-700 bg-white focus:outline-none focus:border-[#E31837] focus:ring-1 focus:ring-[#E31837] transition-colors'
          >
            <option value=''>Select Front Tyre Size...</option>
            {frontTyreSizeList.map((size) => (
              <option key={size.id} value={size.attributes.slug}>
                {size.attributes.size}
              </option>
            ))}
          </select>
        </div>
      )}
      {select === 'rear' && (
        <div>
          <select
            id='rear-tyre-size'
            value={rearTyreSize}
            onChange={(e) => setRearTyreSize(e.target.value)}
            className='w-full border border-gray-300 rounded-md p-2 text-gray-700 bg-white focus:outline-none focus:border-[#E31837] focus:ring-1 focus:ring-[#E31837] transition-colors'
          >
            <option value=''>Select Rear Tyre Size...</option>
            {rearTyreSizeList.map((size) => (
              <option key={size.id} value={size.attributes.slug}>
                {size.attributes.size}
              </option>
            ))}
          </select>
        </div>
      )}
      <button
        className={`w-full py-2 px-4 rounded font-semibold text-white transition-colors ${
          isTyreSizeSelected
            ? 'bg-[#E31837] hover:bg-[#c01530] cursor-pointer'
            : 'bg-gray-400 cursor-not-allowed'
        }`}
        disabled={!isTyreSizeSelected}
        onClick={handleFindTyres}
      >
        FIND TYRES
      </button>
    </div>
  );
};

export default FilterByTyrePos;
