'use client';
import { useEffect, useState } from 'react';
import useProductFilterStore from '@/store/useProductFilterStore';

const HierarchicalFilter = ({ data }: { data: any }) => {
  // Get state and actions from the Zustand store
  const {
    selectedBrand,
    selectedModel,
    selectedTyrePos,
    setBrand,
    setModel,
    setTyrePos,
  } = useProductFilterStore();

  // Local state for the available options in each dropdown
  const [brandList, setBrandList] = useState<string[]>(
    Object.keys(data?.brands)
  );
  const [modelList, setModelList] = useState<string[]>([]);
  const [posList, setPosList] = useState<string[]>([]);

  // Update model list when brand changes
  useEffect(() => {
    if (selectedBrand !== 'Select brand') {
      setModelList(Object?.keys(data?.brands[selectedBrand]?.models));
    } else {
      setModel('Select model');
      setModelList([]);
    }
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, [selectedBrand]);

  // Update position list when model changes
  useEffect(() => {
    if (selectedModel !== 'Select model') {
      setPosList(data?.brands[selectedBrand]?.models[selectedModel]);
    } else {
      setTyrePos('Select tyre position');
    }
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, [selectedModel]);

  // Update position list when tyre position changes
  useEffect(() => {
    if (selectedTyrePos !== 'Select tyre position') {
      setPosList(data?.brands[selectedBrand]?.models[selectedModel]);
    } else {
      setPosList([]);
    }
    // eslint-disable-next-line react-hooks/exhaustive-deps
  }, [selectedTyrePos]);

  return (
    <div className='bg-[#bcbec0] px-[15px] py-[10px] text-center rounded-t-lg'>
      <span className='mb-2 block uppercase text-[12px] font-semibold'>
        Search by Vehicle
      </span>
      <div className='mb-3 '>
        <SelectFilter
          title={'brand'}
          selectedList={brandList}
          handleChange={setBrand}
        />
      </div>
      <div className='mb-3'>
        <SelectFilter
          title={'model'}
          selectedList={modelList}
          handleChange={setModel}
        />
      </div>
      <div className='mb-3'>
        <SelectFilter
          title={'tyre position'}
          selectedList={posList}
          handleChange={setTyrePos}
        />
      </div>
    </div>
  );
};

export default HierarchicalFilter;

export const SelectFilter = ({
  title,
  selectedList,
  handleChange,
}: {
  title: string;
  selectedList: any;
  handleChange: (p: string) => void;
}) => {
  return (
    <select
      className='w-full px-[20px] py-[10px] text-[14px] text-[#666]'
      onChange={(e) => {
        handleChange(e.target.value);
      }}
    >
      <option>Select {title}</option>
      {selectedList?.map((item: string) => {
        return (
          <option key={item} value={item}>
            {item}
          </option>
        );
      })}
    </select>
  );
};
