// src/components/ProductCard.tsx

import Image from 'next/image';
import { ProductProps } from '@/type/strapi-products';
import Link from 'next/link';
import StarRating from '../star-rating';
import { useCartStore } from '@/store/useCartStore';
import { useComparisonStore } from '@/store/useComparisonStore';

export default function ProductCard({ product }: { product: ProductProps }) {
  const { addProduct } = useComparisonStore();
  const { addItemCart } = useCartStore();
  const {
    title,
    price,
    images,
    slug,
    product_category,
    product_subcategory,
    WheelPosition,
  } = product.attributes;
  const imageOne = images?.data?.[0]?.attributes?.url;
  const imageTwo = images?.data?.[1]?.attributes?.url;
  return (
    <div
      key={product?.id}
      className='w-[257px] h-auto group cursor-pointer text-center card-shadow'
    >
      <div className='overflow-hidden w-full h-[257px] relative'>
        <button
          className='bg-[#c5c6c6] mt-3 text-tegblue px-3 py-2 hidden group-hover:block posZ hover:bg-tegred hover:text-white'
          onClick={() => {
            // console.log({ id: product?.id, ...product?.attributes });
            addProduct({ id: product?.id, ...product?.attributes });
          }}
        >
          Add to compare
        </button>
        <div className='absolute mt-3 inset-0 transition-transform duration-500 ease-in-out group-hover:-translate-x-full'>
          <Image
            src={
              imageOne
                ? `${process?.env?.NEXT_PUBLIC_STRAPI_API_URL}${imageOne}`
                : ''
            }
            width={100}
            height={100}
            alt={title}
            style={{ width: '100%' }}
          />
        </div>
        <div className='absolute inset-0 mt-3 transition-transform duration-500 ease-in-out translate-x-full group-hover:translate-x-0'>
          <Image
            src={
              imageTwo
                ? `${process?.env?.NEXT_PUBLIC_STRAPI_API_URL}${imageTwo}`
                : ''
            }
            width={100}
            height={100}
            alt={title}
            style={{ width: '100%' }}
          />
        </div>
      </div>
      <div className='p-3 text-[14px]'>
        <span className='text-tegblue block'>
          {product_category?.data?.attributes?.name +
            ', ' +
            product_subcategory?.data?.attributes?.name}
        </span>
        <span className='text-tegblue mb-3 block'>{WheelPosition}</span>
        <Link href={'/product/' + slug}>
          <h3 className='text-tegred font-bold underline uppercase mb-1'>
            {title}
          </h3>
        </Link>
        <div className='flex justify-center mb-1'>
          <StarRating value={100} />
        </div>
        <span className='text-tegred text-[20px] font-bold block mb-3'>
          ₹{price}
        </span>
        <div className='w-full flex gap-x-2 justify-center'>
          <Link
            href={'/product/' + slug}
            className='bg-tegblue hover:bg-tegblue text-white px-3 py-2 rounded-sm'
            onClick={() => {}}
          >
            View Product
          </Link>
          <button
            className='bg-tegred hover:bg-tegblue text-white px-3 py-2'
            onClick={() => {
              addItemCart({
                id: product?.id?.toString(),
                title: product?.attributes?.title,
                price: product?.attributes?.price?.toString(),
                sku: product?.attributes?.sku,
                permalink: product?.attributes?.slug,
                image: imageOne,
              });
            }}
          >
            Add to cart
          </button>
        </div>
      </div>
    </div>
  );
}
