'use client';
import { useState } from 'react';
import HierarchicalFilter, {
  SelectFilter,
} from '@/components/shared/product/hierarchical-filter';
import { motorcycleData } from '@/database/vehicle-sample-data';
import {
  frontTyreSizeList,
  rearTyreSizeList,
  patternList,
  segmentationList,
} from '@/constants/categories';
import ProductFilterDivider from '../ProductFilterDivider';
import useProductFilterStore from '@/store/useProductFilterStore';

const ProductFilters = () => {
  // Get state and actions from the Zustand store
  const {
    // selectedBrand,
    // selectedModel,
    // selectedTyrePos,
    // selectedFrontTyreSize,
    // selectedRearTyreSize,
    // selectedPattern,
    // selectedSegment,
    // setBrand,
    // setModel,
    // setTyrePos,
    setFrontTyreSize,
    setRearTyreSize,
    setPattern,
    setSegment,
  } = useProductFilterStore();

  // This is UI-specific state, so we keep it local
  const [displayTyreSizeFilter, setDisplayTyreSizeFilter] = useState<string>(
    'Select tyre position'
  );

  return (
    <div>
      <HierarchicalFilter data={motorcycleData} />
      <ProductFilterDivider />
      <div className='bg-[#bcbec0] px-[15px] py-[10px] text-center rounded-t-lg'>
        <span className='mb-2 block uppercase text-[12px] font-semibold'>
          SELECT Front (OR) Rear Tyre Size
        </span>
        <div className='mb-3 '>
          <SelectFilter
            title={'tyre position'}
            selectedList={['Front Tyre', 'Rear Tyre']}
            handleChange={setDisplayTyreSizeFilter}
          />
        </div>
        <div className='mb-3 '>
          {displayTyreSizeFilter === 'Front Tyre' && (
            <SelectFilter
              title={'Front Tyre Size'}
              selectedList={frontTyreSizeList}
              handleChange={setFrontTyreSize}
            />
          )}
          {displayTyreSizeFilter === 'Rear Tyre' && (
            <SelectFilter
              title={'Rear Tyre Size'}
              selectedList={rearTyreSizeList}
              handleChange={setRearTyreSize}
            />
          )}
        </div>
      </div>
      <ProductFilterDivider />
      <div className='bg-[#bcbec0] px-[15px] py-[10px] text-center rounded-t-lg'>
        <span className='mb-2 block uppercase text-[12px] font-semibold'>
          Search by Pattern
        </span>
        <div className='mb-3 '>
          <SelectFilter
            title={'Pattern'}
            selectedList={patternList}
            handleChange={setPattern}
          />
        </div>
      </div>
      <ProductFilterDivider />
      <div className='bg-[#bcbec0] px-[15px] py-[10px] text-center rounded-t-lg'>
        <span className='mb-2 block uppercase text-[12px] font-semibold'>
          Search by Segment
        </span>
        <div className='mb-3 '>
          <SelectFilter
            title={'Product segmentation'}
            selectedList={segmentationList}
            handleChange={setSegment}
          />
        </div>
      </div>
    </div>
  );
};

export default ProductFilters;
