// src/components/ProductList.tsx

import { ProductProps } from '@/type/strapi-products';
import ProductCard from '@/components/shared/product/product-card';
import { useProductStore } from '@/store/useProductStore';

async function getProducts(
  brand: string,
  model: string,
  wheelPosition: string
): Promise<ProductProps[]> {
  let url =
    'https://tyrefinder.co.in/api/products?populate=*&filters[product_category][slug][$eq]=two-wheeler';

  if (brand) {
    url += `&filters[vehicle_brands][slug][$eq]=${brand}`;
  }
  if (model) {
    url += `&filters[vehicle_models][slug][$eq]=${model}`;
  }
  if (wheelPosition) {
    url += `&filters[WheelPosition][$eq]=${encodeURIComponent(wheelPosition)}`;
  }

  const res = await fetch(url, { cache: 'no-store' });

  if (!res.ok) {
    throw new Error('Failed to fetch products');
  }

  const data = await res.json();
  return data.data;
}

export default async function ProductList() {
  const { brand, model, wheelPosition } = useProductStore.getState();
  const products = await getProducts(brand, model, wheelPosition);

  if (products.length === 0) {
    return <p className='text-center text-xl'>No products found.</p>;
  }

  return (
    <div className='grid grid-cols-1 sm:grid-cols-2 md:grid-cols-3 lg:grid-cols-4 gap-6'>
      {products.map((product) => (
        <ProductCard key={product.id} product={product} />
      ))}
    </div>
  );
}
