// src/components/PriceRangeFilter.tsx

'use client';

import React, { useState, useEffect } from 'react';
import { Slider, Box, Typography } from '@mui/material';
import { useProductStore } from '@/store/useProductStore';
import useDebounce from '@/hooks/use-debounce';

const MIN_PRICE = 0;
const MAX_PRICE = 15000; // Adjust this based on your product price range

export default function PriceRangeFilter() {
  const { priceRange, setPriceRange } = useProductStore();
  const [localPriceRange, setLocalPriceRange] = useState(priceRange);
  const debouncedPriceRange = useDebounce(localPriceRange, 500); // 500ms delay

  const handleChange = (event: Event, newValue: number | number[]) => {
    if (Array.isArray(newValue)) {
      setLocalPriceRange({ min: newValue[0], max: newValue[1] });
    }
  };

  useEffect(() => {
    setPriceRange(debouncedPriceRange);
  }, [debouncedPriceRange, setPriceRange]);

  return (
    <Box sx={{ width: '100%', padding: 2 }}>
      <Typography gutterBottom>Price Range</Typography>
      <Slider
        value={[localPriceRange.min, localPriceRange.max]}
        onChange={handleChange}
        valueLabelDisplay='auto'
        min={MIN_PRICE}
        max={MAX_PRICE}
        step={100}
      />
      <Box sx={{ display: 'flex', justifyContent: 'space-between', mt: 2 }}>
        <Typography>₹{localPriceRange.min}</Typography>
        <Typography>₹{localPriceRange.max}</Typography>
      </Box>
    </Box>
  );
}
