import React from 'react';
import reviewData from '@/database/products/product-reviews.json';
import Image from 'next/image';
import StarRating from '../star-rating';
import { FontAwesomeIcon } from '@fortawesome/react-fontawesome';
import { faThumbsUp, faThumbsDown } from '@fortawesome/free-solid-svg-icons';

const Reviews = ({ productId }: { productId: string }) => {
  const tmp = reviewData.filter((itm) => {
    return itm?.post_id === productId;
  });
  const totalRating = tmp.reduce(
    (sum, review) => sum + parseInt(review.rating),
    0
  );
  // console.log(tmp);
  return (
    <div>
      <header className='w-full flex justify-between mb-[50px]'>
        <div className='flex gap-4'>
          <div className='review_header-title text-[16px] text-tegred'>
            {tmp?.length} Reviews
          </div>
          {/* <div>Input Field Goes here</div> */}
        </div>
        <div className='overall-rating'>
          <StarRating value={totalRating / tmp.length} />
        </div>
      </header>
      <div className='review__items'>
        {tmp?.map((revItem, ind) => {
          return (
            <div key={ind}>
              <div className='review__item mb-[30px]'>
                <div className='review_meta flex gap-4 mb-[10px]'>
                  <Image
                    src='https://y9u4s6b5.rocketcdn.me/wp-content/uploads/2021/09/technology-icon1.jpg.webp'
                    width={60}
                    height={60}
                    alt=''
                    className='border border-[#cccccc] rounded-[50%]'
                  />
                  <div>
                    <div className='author mb-1'>
                      <span className='text-[16px] font-light'>
                        {revItem?.author}
                      </span>
                      ,&nbsp;
                      <time className='text-[14px] font-light text-[#7a7a7a]'>
                        {revItem?.date}
                      </time>
                    </div>
                    <div className='rating'>
                      <StarRating value={Number(revItem?.rating)} />
                    </div>
                  </div>
                </div>
                <div className='review__content'>
                  <h3 className='review_title text-[14px] font-semibold text-[#7a7a7a]'>
                    {revItem?.title}
                  </h3>
                  <p className='review_content text-[14px] font-normal text-[#7a7a7a]'>
                    {revItem?.content}
                  </p>
                </div>
                <div className='review_controls flex gap-4'>
                  <div className='control-up flex gap-1 justify-center pointer-cursor'>
                    <FontAwesomeIcon
                      icon={faThumbsUp}
                      size={'sm'}
                      className='mr-1 mt-1'
                      color={'#295ca9'}
                    />
                    <span>0</span>
                  </div>
                  <div className='control-down flex gap-1 justify-center pointer-cursor'>
                    <FontAwesomeIcon
                      icon={faThumbsDown}
                      size={'sm'}
                      className='mr-1 mt-1'
                      color={'#295ca9'}
                    />
                    <span>0</span>
                  </div>
                </div>
              </div>
            </div>
          );
        })}
      </div>
    </div>
  );
};

export default Reviews;
