'use client';
import sanitizeHtml from 'sanitize-html';

export default function RichTextRenderer({ content }: { content: string }) {
  // Sanitize the HTML content
  const sanitizedContent = sanitizeHtml(content, {
    allowedTags: [
      'h1',
      'h2',
      'h3',
      'h4',
      'h5',
      'h6', // Headings
      'p',
      'br',
      'strong',
      'em',
      'u',
      's',
      'blockquote', // Text formatting
      'ol',
      'ul',
      'li', // Lists
      'a',
      'img', // Links and images
      'div',
      'span', // Containers
    ],
    allowedAttributes: {
      a: ['href', 'target', 'rel'], // Allow href, target, and rel attributes for <a> tags
      img: ['src', 'alt', 'width', 'height', 'style'], // Allow src, alt, width, height, and style for <img> tags
    },
    allowedSchemes: ['http', 'https', 'data'], // Allow http, https, and data URLs
  });
  //   const sanitizedContent = content;

  return (
    <div
      className='prose prose-lg max-w-none' // Use TailwindCSS Typography for styling
      dangerouslySetInnerHTML={{ __html: sanitizedContent }}
    />
  );
}
