import React from 'react';

const StarRating = ({ value }: { value: number }) => {
  // Calculate the rating out of 5
  const rating = Math.min(Math.max(value / 20, 0), 5); // Clamp value between 0 and 5

  // Determine full stars, half stars, and empty stars
  const fullStars = Math.floor(rating);
  const hasHalfStar = rating % 1 >= 0.5;
  const emptyStars = 5 - fullStars - (hasHalfStar ? 1 : 0);

  return (
    <div className='flex items-center text-[20px]'>
      {/* Render full stars */}
      {[...Array(fullStars)].map((_, i) => (
        <span key={`full-${i}`} className='text-[#295ca9]'>
          ★
        </span>
      ))}
      {/* Render half star */}
      {hasHalfStar && <span className='text-[#295ca9]'>☆</span>}
      {/* Render empty stars */}
      {[...Array(emptyStars)].map((_, i) => (
        <span key={`empty-${i}`} className='text-gray-300'>
          ★
        </span>
      ))}
    </div>
  );
};

export default StarRating;
