import { tertiary } from '@/constants/colors';
import { mmTwoWheeler } from '@/constants/navigation-menu';
import Link from 'next/link';
import React from 'react';
import Icon from '@/components/shared/icons/Icon';

interface MegaMenuChildItemProps {
  id: string;
  route: string | null;
  text: string;
  icon: string;
}

const TwoColumnMenu = ({
  megamenuitems,
  columns,
}: {
  megamenuitems: MegaMenuChildItemProps[];
  columns: number;
}) => {
  return (
    <ul
      className={`grid ${
        columns === 2 ? 'grid-cols-2' : 'grid-cols-3'
      } gap-x-5`}
    >
      {megamenuitems?.map(
        (megamenuitem: MegaMenuChildItemProps, index: number) => {
          return (
            <li key={megamenuitem?.id} className={`py-2 border-b`}>
              <Link href={megamenuitem?.route ?? ''} className='flex'>
                <span className='w-[20px] h-[20px] block text-[12px]'>
                  <Icon icon={megamenuitem?.icon} color={tertiary?.default} />
                </span>
                <p className='text-[13px] text-white font-sans hover:text-primary-yellow py-3 lg:py-0 lg:px-[15px] flex gap-y-4 items-center text-left'>
                  {megamenuitem?.text}
                </p>
              </Link>
            </li>
          );
        }
      )}
    </ul>
  );
};

export default TwoColumnMenu;
