"use client";

import { FontAwesomeIcon } from "@fortawesome/react-fontawesome"
import { IconProp } from "@fortawesome/fontawesome-svg-core";
import Image from "next/image";
import { useState } from "react";

interface TyreGuideVideoCardProps {
    id: number;
    videoicon: IconProp;
    text: string;
    link: string;
    videoimage:string;
    videoUrl: string;
}

const TyreGuideVideoCard = ({ tyrevideodata }: { tyrevideodata: TyreGuideVideoCardProps }) => {
    const [isPopupOpen, setIsPopupOpen] = useState(false);

    const openPopup = () => {
        setIsPopupOpen(true);
    }

    const closePopup = () => {
        setIsPopupOpen(false);
    };

    return <div className="py-6 my-5">
        <div className="bg-white-500 p-[15px] text-center">
            <div>
                <div className="align-middle">                
                    <div className="bg-red-600 rounded-full inline-block">
                        <FontAwesomeIcon
                            icon={tyrevideodata.videoicon}
                            size={'sm'}
                            className='py-1 px-2  inline-block text-center'
                            color={'#ffffff'}
                        />
                    </div>
                    <p className="ml-2 text-lg uppercase mb-5 inline-block text-[#295CA9] text-lg font-medium tracking-tight">{tyrevideodata?.text}</p>
                </div>
                <div onClick={openPopup} className="cursor-pointer">
                    <Image
                        src={tyrevideodata.videoimage} 
                        alt=''
                        width={255}
                        height={143}
                        className="w-[255px] h-[143px] inline-block mb-5"
                    />
                </div>
            </div>  
            <a href={tyrevideodata.link} className="text-white py-2 px-5 bg-blue-700 hover:bg-red-600 text-sm inline-block align-middle rounded-[10px]">
                More Videos</a>
        </div>
        {isPopupOpen && (
                <div className="fixed inset-0 bg-black bg-opacity-50 flex justify-center items-center z-50">
                    <div className="bg-white p-5 rounded-lg relative w-[90%] max-w-[800px]">
                        {/* Close button */}
                        <button
                            onClick={closePopup}
                            className="absolute top-2 right-2 text-gray-700 hover:text-red-600"
                        >
                            &times;
                        </button>
                        {/* Embedded iframe video */}
                        <iframe
                            src={tyrevideodata.videoUrl}
                            width="100%"
                            height="400"
                            allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture"
                            allowFullScreen
                            title="Embedded Video"
                        ></iframe>
                    </div>
                </div>
            )}
    </div>
}
export default TyreGuideVideoCard