"use client"

import { useEffect, useRef } from "react"

export default function VideoBanner() {
  const iframeRef = useRef<HTMLIFrameElement>(null)

  useEffect(() => {
    // Adjust iframe size to cover the container
    const adjustIframeSize = () => {
      if (!iframeRef.current) return

      const container = iframeRef.current.parentElement
      if (!container) return

      const containerWidth = container.offsetWidth
      const containerHeight = container.offsetHeight
      const aspectRatio = 16 / 9

      let width = containerWidth
      let height = containerWidth / aspectRatio

      if (height < containerHeight) {
        height = containerHeight
        width = containerHeight * aspectRatio
      }

      iframeRef.current.style.width = `${width}px`
      iframeRef.current.style.height = `${height}px`
      iframeRef.current.style.left = `${(containerWidth - width) / 2}px`
      iframeRef.current.style.top = `${(containerHeight - height) / 2}px`
    }

    adjustIframeSize()
    window.addEventListener("resize", adjustIframeSize)

    return () => {
      window.removeEventListener("resize", adjustIframeSize)
    }
  }, [])

  return (
    <section className="relative h-[180px] sm:h-[200px] md:h-[250px] flex items-center justify-center overflow-hidden mb-[2%]">
      {/* Video Background Container */}
      <div className="absolute inset-0 overflow-hidden">
        <iframe
          ref={iframeRef}
          className="absolute"
          frameBorder="0"
          allowFullScreen
          allow="accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture; web-share"
          title="Background Video"
          src="https://www.youtube.com/embed/hic0YYdJYNQ?controls=0&rel=0&playsinline=1&cc_load_policy=0&autoplay=1&mute=1&loop=1&playlist=hic0YYdJYNQ"
        ></iframe>
      </div>

      {/* Dark Overlay */}
      <div className="absolute inset-0 bg-black/50"></div>

      {/* Content */}
      <div className="container mx-auto px-4 relative z-10 text-center">
        <h1 className="text-3xl md:text-4xl font-bold text-white mb-2 md:mb-4">Video Testimonials</h1>
        <p className="text-base md:text-xl text-white">
          Watch our Mechanic Partners, Distributors, Retailers and Experts Speak
        </p>
      </div>
    </section>
  )
}

