import { create } from "zustand"
import { persist } from "zustand/middleware"

interface ShareCount {
  email: number
  whatsapp: number
  facebook: number
  linkedin: number
  twitter: number
  pinterest: number
}

interface ShareState {
  shareCounts: ShareCount
  totalShares: number
  incrementShareCount: (platform: string) => void
  getShareCount: (platform: string) => number
}

export const useShareStore = create<ShareState>()(
  persist(
    (set, get) => ({
      shareCounts: {
        email: 0,
        whatsapp: 0,
        facebook: 0,
        linkedin: 0,
        twitter: 0,
        pinterest: 0,
      },
      totalShares: 0,

      incrementShareCount: (platform) => {
        set((state) => {
          const newCounts = { ...state.shareCounts }

          if (platform in newCounts) {
            newCounts[platform as keyof ShareCount] += 1
          }

          return {
            shareCounts: newCounts,
            totalShares: state.totalShares + 1,
          }
        })
      },

      getShareCount: (platform) => {
        const { shareCounts } = get()
        return platform in shareCounts ? shareCounts[platform as keyof ShareCount] : 0
      },
    }),
    {
      name: "blog-share-storage",
    },
  ),
)

