import { create } from 'zustand';
import { persist } from 'zustand/middleware';
import type { ProductDetailedProp } from '@/type/strapi-products';

interface ComparisonStore {
  compareProducts: any[];
  addProduct: (product: any) => void;
  removeProduct: (productId: any) => void;
  clearComparison: () => void;
  isComparisonFull: () => boolean;
}

export const useComparisonStore = create<ComparisonStore>()(
  persist(
    (set, get) => ({
      compareProducts: [],
      addProduct: (product) =>
        set((state) => {
          // Check if we already have 3 products or if this product is already in the comparison
          if (
            state.compareProducts.length >= 3 ||
            state.compareProducts.some((p) => p.id === product.id)
          ) {
            return state;
          }
          return { compareProducts: [...state.compareProducts, product] };
        }),
      removeProduct: (productId) =>
        set((state) => ({
          compareProducts: state.compareProducts.filter(
            (p) => p.id !== productId
          ),
        })),
      clearComparison: () => set({ compareProducts: [] }),
      isComparisonFull: () => get().compareProducts.length >= 3,
    }),
    {
      name: 'product-comparison-storage',
    }
  )
);
