// src/store/productStore.ts

import { create } from 'zustand';
import { ProductProps } from '@/type/strapi-products';
interface PriceRange {
  min: number;
  max: number;
}

interface ProductState {
  products: ProductProps[];
  setProducts: (products: ProductProps[]) => void;
  brand: string;
  setBrand: (brand: string) => void;
  model: string;
  setModel: (model: string) => void;
  wheelPosition: string;
  setWheelPosition: (position: string) => void;
  priceRange: PriceRange;
  setPriceRange: (range: PriceRange) => void;
  frontTyreSize: string;
  setFrontTyreSize: (size: string) => void;
  rearTyreSize: string;
  setRearTyreSize: (size: string) => void;
  pattern: string;
  setPattern: (pattern: string) => void;
  segment: string;
  setSegment: (segment: string) => void;
  select: string;
  setSelect: (select: string) => void;
}

export const useProductStore = create<ProductState>((set) => ({
  products: [],
  setProducts: (products) => set({ products }),
  brand: '',
  setBrand: (brand) => set({ brand }),
  model: '',
  setModel: (model) => set({ model }),
  wheelPosition: '',
  setWheelPosition: (position) => set({ wheelPosition: position }),
  priceRange: { min: 0, max: 15000 }, // Initial price range
  setPriceRange: (range) => set({ priceRange: range }),
  frontTyreSize: '',
  setFrontTyreSize: (size) => set({ frontTyreSize: size }),
  rearTyreSize: '',
  setRearTyreSize: (size) => set({ rearTyreSize: size }),
  pattern: '',
  setPattern: (pattern) => set({ pattern }),
  segment: '',
  setSegment: (segment) => set({ segment }),
  select: '',
  setSelect: (select) => set({ select }),
}));
