export interface DataAttributes<T> {
  data: {
    id: number;
    attributes: T;
  }[];
}
export interface DataAttribute<T> {
  data: {
    id: number;
    attributes: T;
  };
}

export interface ImageDataProp {
  id: number;
  attributes: {
    name: string;
    alternativeText: string | null;
    caption: string | null;
    width: number;
    height: number;
    formats: {
      thumbnail: {
        name: string;
        hash: string;
        ext: string;
        mime: string;
        path: string | null;
        width: number;
        height: number;
        size: number;
        sizeInBytes: number;
        url: string;
      };
      medium: {
        name: string;
        hash: string;
        ext: string;
        mime: string;
        path: string | null;
        width: number;
        height: number;
        size: number;
        sizeInBytes: number;
        url: string;
      };
      small: {
        name: string;
        hash: string;
        ext: string;
        mime: string;
        path: string | null;
        width: number;
        height: number;
        size: number;
        sizeInBytes: number;
        url: string;
      };
    };
    hash: string;
    ext: string;
    mime: string;
    size: number;
    url: string;
    previewUrl: string | null;
    provider: string;
    provider_metadata: string | null;
    createdAt: string;
    updatedAt: string;
  };
}

interface ImageData {
  data: ImageDataProp[];
}

// Specific interfaces for each attribute type
interface ProductPatternAttributes {
  name: string;
  slug: string;
  createdAt: string;
  updatedAt: string;
  publishedAt: string;
}

interface ProductCategoryAttributes {
  name: string;
  slug: string;
  createdAt: string;
  updatedAt: string;
  publishedAt: string;
}

interface ProductAttributeItem {
  attributename: string;
  createdAt: string;
  updatedAt: string;
  publishedAt: string;
  slug: string;
}

interface ProductAttributes {
  data: {
    id: number;
    attributes: ProductAttributeItem;
  }[];
}

export interface ProductProps {
  data: any;
  id: number;
  attributes: {
    title: string;
    createdAt: string;
    updatedAt: string;
    publishedAt: string;
    content: string;
    sku: string;
    shortdescription: string;
    date: string;
    regularPrice: number;
    salePrice: number;
    stockStatus: string;
    ProductVisibility: string;
    WheelPosition: string;
    product360ViewerField: string;
    rankmathtitle: string;
    rankmathdescription: string;
    rankmathfocuskeyword: string;
    price: number;
    slug: string;
    images: ImageData;
    productvideourl: { data: null };
    product_pattern: DataAttributes<ProductPatternAttributes>;
    road_weather_condition: DataAttributes<ProductCategoryAttributes>; // Use the generic interface
    product_category: DataAttribute<ProductCategoryAttributes>; // Use the generic interface
    product_subcategory: DataAttribute<ProductCategoryAttributes>; // Use the generic interface
    product_segmentation: DataAttributes<ProductCategoryAttributes>; // Use the generic interface
    front_tyresize: DataAttributes<{
      size: string;
      slug: string;
      createdAt: string;
      updatedAt: string;
      publishedAt: string;
    }>;
    rear_tyresize: DataAttributes<{
      size: string;
      slug: string;
      createdAt: string;
      updatedAt: string;
      publishedAt: string;
    }>; // Example
    product_reviews: { data: [] };
    surface_condition: DataAttributes<ProductCategoryAttributes>; // Use the generic interface
    weather_condition: DataAttributes<ProductCategoryAttributes>; // Use the generic interface
    vehicle_brands: DataAttributes<{
      brandName: string;
      slug: string;
      createdAt: string;
      updatedAt: string;
      publishedAt: string;
    }>; // Example
    vehicle_models: DataAttributes<{
      modelName: string;
      slug: string;
      createdAt: string;
      updatedAt: string;
      publishedAt: string;
    }>; // Example
    product_benefits: DataAttributes<{
      id: string;
      attributes: {
        title: string;
        Description: string;
        createdAt: string;
        updatedAt: string;
        publishedAt: string;
      };
    }>; // Example
    product_features: DataAttributes<{
      title: string;
      Description: string;
      createdAt: string;
      updatedAt: string;
      publishedAt: string;
    }>; // Example
    product_technologies: DataAttributes<{
      title: string;
      description: string;
      createdAt: string;
      updatedAt: string;
      publishedAt: string;
    }>; // Example
    product_attributes: ProductAttributes;
  };
}

// Update the ProductDetailedProp type to match our new API response structure
export interface ProductDetailedProp {
  id: number;
  title: string;
  price: number;
  slug: string;
  wheelPosition: string;
  content?: string;
  shortdescription?: string;
  sku?: string;
  regularPrice?: number;
  salePrice?: number;
  stockStatus?: string;
  product_subcategory?: {
    data?: {
      attributes?: {
        name?: string;
      };
    };
  };
  images: {
    id: number;
    url: string;
    alt?: string;
    thumbnail?: string;
  }[];
  product_attributes?: {
    data?: Array<{
      id: number;
      attributes?: {
        attributename?: string;
        slug?: string;
      };
    }>;
  };
}
